#
# Partial translation of FAQ-O-Matic to Finnish by Anssi Johansson
# Date of last change: Aug 20 2001 22:33
# Patches/fixes/comments are welcome. I didn't have that much time
# when doing this particular translation, sorry.
#
# email: fi-faq-translation@miuku.net
#

sub translations {
	my $tx = shift;
	my $txfile = <<'__EOF__';

###
### submitItem.pm
###

msgid "Changed the item title, was "%0""
msgstr "Vaihdettiin otsikkoa, oli "%0""

msgid "New Subcategory of "%0""
msgstr "%0:n uusi alaryhmä"

###
### groups.pm (OK!)
###

msgid "Select a group to edit:"
msgstr "Valitse muokattava käyttäjäryhmä:"

msgid "(Members of this group are allowed to access these group definition pages.)"
msgstr "(Tämän käyttäjäryhmän jäsenten sallitaan käyttää näitä ryhmän määrittelysivuja.)"

msgid "Add Group"
msgstr "Lisää käyttäjäryhmä"

msgid "Up To List Of Groups"
msgstr "Takaisin käyttäjäryhmien listalle"

msgid "Remove Member"
msgstr "Poista jäsen käyttäjäryhmästä"

msgid "Add Member"
msgstr "Lisää jäsen käyttäjäryhmään"

msgid "Go to the Faq-O-Matic"
msgstr "Takaisin FAQ-O-Maticiin"

msgid "Go To Install/Configuration Page"
msgstr "Takaisin asennus- ja asetussivulle"

###
### submitModOptions.pm
###

### 
### submitItem.pm
###

msgid "The file"
msgstr "Tiedostoa"

msgid "doesn't exist."
msgstr "ei ole olemassa."

msgid "Your browser or WWW cache has truncated your POST."
msgstr "Selaimesi tai WWW-välimuistipalvelimesi keskeytti tietojen lähettämisen."

msgid "Changed the item title, was"
msgstr "Vaihdettiin otsikkoa, oli"

msgid "Your part order list"
msgstr "Uudessa osien järjestyslistassasi on vikaa:"

msgid "doesn't have the same number of parts"
msgstr "siinä ei ole yhtä monta osaa kuin alkuperäisessä."

msgid "as the original item."
msgstr ""

msgid "doesn't say what to do with part"
msgstr "siinä ei kerrota mitä pitäisi tehdä osalle"

###
### submitMove.pm
###

msgid "The moving file"
msgstr "Siirrettävä tiedosto"

msgid "is broken or missing."
msgstr "on rikki tai sitä ei ole olemassa."

msgid "The newParent file"
msgstr "Kohdetiedosto"

msgid "The oldParent file"
msgstr "Lähdetiedosto"

msgid "The new parent"
msgstr "Kohde"

msgid "is the same as the old parent."
msgstr "on sama kuin lähde."

msgid "is the same as the item you want to move."
msgstr "on sama kuin siirrettävä."

msgid "is a child of the item being moved"
msgstr "on siirrettävän tiedon alapuolella"

msgid "You can't move the top item."
msgstr "Et voi siirtää ylimmäistä tietoa."

msgid "moved a sub-item to"
msgstr "siirretty tieto kohteeseen"

msgid "moved a sub-item from"
msgstr "siirretty tieto kohteesta"

###
### submitPass.pm
###


msgid "I sent email to you at "%0". It should arrive soon, containing a URL."
msgstr "Lähetin sähköpostin osoitteeseen %0. Sen pitäisi saapua muutaman minuutin kuluttua ja siinä on WWW-osoite."

msgid "Either open the URL directly or paste the secret into the form below and click Validate."
msgstr "Siirry sähköpostissa mainittuun osoitteeseen tai kirjoita sähköpostissa oleva tunniste tähän ja paina Varmista."




msgid "An email address must look like"
msgstr "Sähköpostiosoite täytyy olla muotoa"

msgid "If yours"
msgstr "Jos sinun"

msgid "does and I keep rejecting it, please mail"
msgstr "on sellainen ja tämä järjestelmä hylkää sen silti, lähetä sähköpostia osoitteeseen"

msgid "and tell him what's happening."
msgstr "ja kerro ongelmasta."

msgid "Your password may not contain spaces or carriage returns."
msgstr "Salasanassasi ei saa olla välilyöntejä eikä rivinvaihtoja."

msgid "Your Faq-O-Matic authentication secret"
msgstr "Sinun Faq-O-Matic -tunnisteesi"

msgid "I couldn't mail the authentication secret to"
msgstr "En voinut lähettää tunnistetietoja osoitteeseen "

msgid "and I'm not sure why."
msgstr "enkä ole ihan varma miksi."

msgid "The secret you entered is not correct."
msgstr "Antamasi tunniste ei ole oikein."

msgid "Did you copy and paste the secret or the URL completely?"
msgstr "Kopioitko varmasti tunnisteen tai WWW-osoitteen oikein?"

msgid "I sent email to you at"
msgstr "Lähetin sinulle sähköpostia osoitteeseen"

msgid "It should arrive soon, containing a URL. Either open the URL directly, or paste the secret into the form below and click Validate."
msgstr "Sen pitäisi saapua pian ja siinä on mukana WWW-osoite. Voit joko klikata WWW-osoitetta suoraan tai kirjoittaa tunnisteen allaolevaan kenttään ja painaa Varmista-nappia."

msgid "Thank you for taking the time to sign up."
msgstr "Kiitos kirjoittautumisestasi"

msgid "Secret:"
msgstr "Tunniste:"

msgid "Validate"
msgstr "Varmista"

###
### editModOptions.pm
###

###
### selectBag.pm
###

###
### submitAnsToCat.pm
###

###
### submitCatToAns.pm
###

###
### OMatic.pm
###

msgid "Warnings:"
msgstr "Varoitukset:"

###
### install.pm
###

msgid "Faq-O-Matic Installer"
msgstr "Faq-O-Matic asennusohjelma"

msgid "failed:"
msgstr "epäonnistui:"

msgid "Unknown step:"
msgstr "Tuntematon vaihe:"

msgid "Updating config to reflect new meta location"
msgstr "Päivitetään asetukset uutta metatiedon paikkaa varten"

msgid "(Can't find <b>config</b> in '$meta' -- assuming this is a new installation.)"
msgstr "(En löydä tiedostoa <b>config</b> hakemistosta '$meta' -- oletan tämän olevan uusi asennus.)"

msgid "Click here"
msgstr "Klikkaa tästä"

msgid "to create"
msgstr "luodaksesi"

msgid "If you want to change the CGI stub to point to another directory, edit the script and then\n"
msgstr "If you want to change the CGI stub to point to another directory, edit the script and then\n"

msgid "click here to use the new location"
msgstr "click here to use the new location"

msgid "FAQ-O-Matic stores files in two main directories.<p>The <b>meta/</b> directory path is encoded in your CGI stub ($0). It contains:"
msgstr "FAQ-O-Matic stores files in two main directories.<p>The <b>meta/</b> directory path is encoded in your CGI stub ($0). It contains:"

msgid "<ul><li>the <b>config</b> file that tells FAQ-O-Matic where everything else lives. That's why the CGI stub needs to know where meta/ is, so it can figure out the rest of its configuration. <li>the <b>idfile</b> file that lists user identities. Therefore, meta/ should not be accessible via the web server. <li>the <b>RCS/</b> subdirectory that tracks revisions to FAQ items. <li>various hint files that are used as FAQ-O-Matic runs. These can be regenerated automatically.</ul>"
msgstr "<ul><li>the <b>config</b> file that tells FAQ-O-Matic where everything else lives. That's why the CGI stub needs to know where meta/ is, so it can figure out the rest of its configuration. <li>the <b>idfile</b> file that lists user identities. Therefore, meta/ should not be accessible via the web server. <li>the <b>RCS/</b> subdirectory that tracks revisions to FAQ items. <li>various hint files that are used as FAQ-O-Matic runs. These can be regenerated automatically.</ul>"

msgid "<p>The <b>serve/</b> directory contains three subdirectories <b>item/</b>, <b>cache/</b>, and <b>bags/</b>. These directories are created and populated by the FAQ-O-Matic CGI, but should be directly accessible via the web server (without invoking the CGI)."
msgstr "<p>The <b>serve/</b> directory contains three subdirectories <b>item/</b>, <b>cache/</b>, and <b>bags/</b>. These directories are created and populated by the FAQ-O-Matic CGI, but should be directly accessible via the web server (without invoking the CGI)."

msgid "<ul><li>serve/item/ contains only FAQ-O-Matic formatted source files, which encode both user-entered text and the hierarchical structure of the answers and categories in the FAQ. These files are only accessed through the web server (rather than the CGI) when another FAQ-O-Matic is mirroring this one. <li>serve/cache/ contains a cache of automatically-generated HTML versions of FAQ answers and categories. When possible, the CGI directs users to the cache to reduce load on the server. (CGI hits are far more expensive than regular file loads.) <li>serve/bags/ contains image files and other ``bags of bits.'' Bit-bags can be linked to or inlined into FAQ items (in the case of images). </ul>"
msgstr "<ul><li>serve/item/ contains only FAQ-O-Matic formatted source files, which encode both user-entered text and the hierarchical structure of the answers and categories in the FAQ. These files are only accessed through the web server (rather than the CGI) when another FAQ-O-Matic is mirroring this one. <li>serve/cache/ contains a cache of automatically-generated HTML versions of FAQ answers and categories. When possible, the CGI directs users to the cache to reduce load on the server. (CGI hits are far more expensive than regular file loads.) <li>serve/bags/ contains image files and other ``bags of bits.'' Bit-bags can be linked to or inlined into FAQ items (in the case of images). </ul>"

msgid "I don't have write permission to <b>$meta</b>."
msgstr "Ei kirjoitusoikeutta <b>$meta</b>-hakemistoon."

msgid "I couldn't create"
msgstr "En voinut luoda"

msgid "Created"
msgstr "Luotu"

msgid "I don't have write permission to"
msgstr "Ei kirjoitusoikeutta: "

msgid "Created new config file."
msgstr "Luotu uusi config-tiedosto."

msgid "Couldn't create"
msgstr "En voinut luoda"

msgid "The idfile exists."
msgstr "idfile on jo olemassa."

msgid "Configuration Main Menu (install module)"
msgstr "Configuration Main Menu (install module)"

msgid "Perform these tasks in order to prepare your FAQ-O-Matic version %0:"
msgstr "Perform these tasks in order to prepare your FAQ-O-Matic version %0:"

msgid "Define configuration parameters."
msgstr "Define configuration parameters."

msgid "Set your password and turn on installer security"
msgstr "Set your password and turn on installer security"

msgid "(Need to configure"
msgstr "(Need to configure"

msgid "(Installer security is on.)"
msgstr "(Installer security is on.)"

msgid "Create item, cache, and bags directories in serve dir."
msgstr "Create item, cache, and bags directories in serve dir."

msgid "Copy old items</a> from"
msgstr "Copy old items</a> from"

msgid "to"
msgstr "to"

msgid "Install any new items that come with the system."
msgstr "Install any new items that come with the system."

msgid "Create system default items."
msgstr "Create system default items."

msgid "Rebuild the cache and dependency files."
msgstr "Rebuild the cache and dependency files."

msgid "Install system images and icons."
msgstr "Install system images and icons."

msgid "Update mirror from master now. (this can be slow!)"
msgstr "Update mirror from master now. (this can be slow!)"

msgid "Set up the maintenance cron job"
msgstr "Set up the maintenance cron job"

msgid "Run maintenance script manually now"
msgstr "Run maintenance script manually now"

msgid "(Need to set up the maintenance cron job first)"
msgstr "(Need to set up the maintenance cron job first)"

msgid "Mark the config file as upgraded to Version"
msgstr "Mark the config file as upgraded to Version"

msgid "Select custom colors for your Faq-O-Matic</a> (optional)"
msgstr "Select custom colors for your Faq-O-Matic</a> (optional)"

msgid "Define groups</a> (optional)"
msgstr "Define groups</a> (optional)"

msgid "Upgrade to CGI.pm version 2.49 or newer."
msgstr "Upgrade to CGI.pm version 2.49 or newer."

msgid "(optional; older versions have bugs that affect bags)"
msgstr "(optional; older versions have bugs that affect bags)"

msgid "You are using version"
msgstr "You are using version"

msgid "now"
msgstr "now"

msgid "Bookmark this link to be able to return to this menu."
msgstr "Bookmark this link to be able to return to this menu."

msgid "(need to turn on installer security)"
msgstr "(need to turn on installer security)"

msgid "Other available tasks:"
msgstr "Other available tasks:"

msgid "See access statistics."
msgstr "See access statistics."

msgid "Examine all bags."
msgstr "Examine all bags."

msgid "Check for unreferenced bags (not linked by any FAQ item)."
msgstr "Check for unreferenced bags (not linked by any FAQ item)."

msgid "The Faq-O-Matic modules are version"
msgstr "The Faq-O-Matic modules are version"

msgid "I wasn't able to change the permissions on"
msgstr "I wasn't able to change the permissions on"

msgid "to 755 (readable/searchable by all)."
msgstr "to 755 (readable/searchable by all)."

msgid "updated config file:"
msgstr "updated config file:"

msgid "Redefine configuration parameters to ensure that"
msgstr "Redefine configuration parameters to ensure that"

msgid "is valid."
msgstr "is valid."

msgid "Jon made a mistake here; key=$key, property=$property."
msgstr "Jon made a mistake here; key=$key, property=$property."

msgid "<b>Mandatory:</b> System information"
msgstr "<b>Mandatory:</b> System information"

msgid "Identity of local FAQ-O-Matic administrator (an email address)"
msgstr "Identity of local FAQ-O-Matic administrator (an email address)"

msgid "A command FAQ-O-Matic can use to send mail. It must either be sendmail, or it must understand the -s (Subject) switch."
msgstr "A command FAQ-O-Matic can use to send mail. It must either be sendmail, or it must understand the -s (Subject) switch."

msgid "The command FAQ-O-Matic can use to install a cron job."
msgstr "The command FAQ-O-Matic can use to install a cron job."

msgid "RCS ci command."
msgstr "RCS ci command."

msgid "<b>Mandatory:</b> Server directory configuration"
msgstr "<b>Mandatory:</b> Server directory configuration"

msgid "Filesystem directory where FAQ-O-Matic will keep item files, image and other bit-bag files, and a cache of generated HTML files. This directory must be accesible directly via the http server. It might be something like /home/faqomatic/public_html/fom-serve/"
msgstr "Filesystem directory where FAQ-O-Matic will keep item files, image and other bit-bag files, and a cache of generated HTML files. This directory must be accesible directly via the http server. It might be something like /home/faqomatic/public_html/fom-serve/"

msgid "Use the"
msgstr "Use the"

msgid "links to change the color of a feature.\n"
msgstr "links to change the color of a feature.\n"

msgid "An Item Title"
msgstr "An Item Title"

msgid "A regular part is how most of your content will appear. The text colors should be most pleasantly readable on this background."
msgstr "A regular part is how most of your content will appear. The text colors should be most pleasantly readable on this background."

msgid "A new link"
msgstr "A new link"

msgid "A visited link"
msgstr "A visited link"

msgid "A search hit"
msgstr "A search hit"

msgid "A directory part should stand out"
msgstr "A directory part should stand out"

msgid "Regular text color"
msgstr "Regular text color"

msgid "Link color"
msgstr "Link color"

msgid "Visited link color"
msgstr "Visited link color"

msgid "to proceed to the"
msgstr "to proceed to the"

msgid "step"
msgstr "step"

msgid "Select a color for"
msgstr "Select a color for"

msgid "Or enter an HTML color specification manually:"
msgstr "Or enter an HTML color specification manually:"

msgid "Select"
msgstr "Select"

msgid "The URL prefix needed to access files in"
msgstr "The URL prefix needed to access files in"

msgid "It should be relative to the root of the server (omit http://hostname:port, but include a leading /). It should also end with a /."
msgstr "It should be relative to the root of the server (omit http://hostname:port, but include a leading /). It should also end with a /."

msgid "<i>Optional:</i> Miscellaneous configurations"
msgstr "<i>Optional:</i> Miscellaneous configurations"

msgid "If this parameter is set, this FAQ will become a mirror of the one at the given URL. The URL should be the base name of the CGI script of the master FAQ-O-Matic."
msgstr "If this parameter is set, this FAQ will become a mirror of the one at the given URL. The URL should be the base name of the CGI script of the master FAQ-O-Matic."

msgid "An HTML fragment inserted at the top of each page. You might use this to place a corporate logo."
msgstr "An HTML fragment inserted at the top of each page. You might use this to place a corporate logo."

msgid "The width= tag in a table. If your"
msgstr "The width= tag in a table. If your"

msgid "has"
msgstr "has"

msgid "you will want to make this empty."
msgstr "you will want to make this empty."

msgid "An HTML fragment appended to the bottom of each page. You might use this to identify the webmaster for this site."
msgstr "An HTML fragment appended to the bottom of each page. You might use this to identify the webmaster for this site."

msgid "Where FAQ-O-Matic should send email when it wants to alert the administrator (usually same as"
msgstr "Where FAQ-O-Matic should send email when it wants to alert the administrator (usually same as"

msgid "If true, FAQ-O-Matic will mail the log file to the administrator whenever it is truncated."
msgstr "If true, FAQ-O-Matic will mail the log file to the administrator whenever it is truncated."

msgid "User to use for RCS ci command (default is process UID)"
msgstr "User to use for RCS ci command (default is process UID)"

msgid "Links from cache to CGI are relative to the server root, rather than absolute URLs including hostname:"
msgstr "Links from cache to CGI are relative to the server root, rather than absolute URLs including hostname:"

msgid "mailto: links can be rewritten such as"
msgstr "mailto: links can be rewritten such as"

msgid "or e-mail addresses suppressed entirely (hide)."
msgstr "or e-mail addresses suppressed entirely (hide)."

msgid "Number of seconds that authentication cookies remain valid. These cookies are stored in URLs, and so can be retrieved from a browser history file. Hence they should usually time-out fairly quickly."
msgstr "Number of seconds that authentication cookies remain valid. These cookies are stored in URLs, and so can be retrieved from a browser history file. Hence they should usually time-out fairly quickly."

msgid "<i>Optional:</i> These options set the default [Appearance] modes."
msgstr "<i>Optional:</i> These options set the default [Appearance] modes."

msgid "Page rendering scheme. Do not choose"
msgstr "Page rendering scheme. Do not choose"

msgid "as the default."
msgstr "as the default."

msgid "show"
msgstr "näytä"

msgid "hide"
msgstr "piilota"

msgid "compact"
msgstr "tiivistetty"

msgid "<i>Optional:</i> These options fine-tune the appearance of editing features."
msgstr "<i>Optional:</i> These options fine-tune the appearance of editing features."

msgid "The old [Show Edit Commands] button appears in the navigation bar."
msgstr "The old [Show Edit Commands] button appears in the navigation bar."

msgid "Navigation links appear at top of page as well as at the bottom."
msgstr "Navigation links appear at top of page as well as at the bottom."

msgid "Hide [Append to This Answer] and [Add New Answer in ...] buttons."
msgstr "Hide [Append to This Answer] and [Add New Answer in ...] buttons."

msgid "icons-and-label"
msgstr "icons-and-label"

msgid "Editing commands appear with neat-o icons rather than [In Brackets]."
msgstr "Editing commands appear with neat-o icons rather than [In Brackets]."

msgid "<i>Optional:</i> Other configurations that you should probably ignore if present."
msgstr "<i>Optional:</i> Other configurations that you should probably ignore if present."

msgid "Draw Item titles John Nolan's way."
msgstr "Draw Item titles John Nolan's way."

msgid "Hide sibling (Previous, Next) links"
msgstr "Hide sibling (Previous, Next) links"

msgid "Arguments to make ci quietly log changes (default is probably fine)"
msgstr "Arguments to make ci quietly log changes (default is probably fine)"

msgid "off"
msgstr "pois päältä"

msgid "true"
msgstr "tosi"

msgid "cheesy"
msgstr "outo"

msgid "This is a command, so only letters, hyphens, and slashes are allowed."
msgstr "This is a command, so only letters, hyphens, and slashes are allowed."

msgid "If this is your first time installing a FAQ-O-Matic, I recommend"
msgstr "If this is your first time installing a FAQ-O-Matic, I recommend"

msgid "only filling in the sections marked <b>Mandatory</b>."
msgstr "only filling in the sections marked <b>Mandatory</b>."

msgid "Define"
msgstr "Define"

msgid "(no description)"
msgstr "(no description)"

msgid "Unrecognized config parameter"
msgstr "Unrecognized config parameter"

msgid "Please report this problem to"
msgstr "Please report this problem to"

msgid "Cron job installed. The maintenance script should run hourly."
msgstr "Cron job installed. The maintenance script should run hourly."

msgid "I thought I installed a new cron job, but it didn't"
msgstr "I thought I installed a new cron job, but it didn't"

msgid "appear to take."
msgstr "appear to take."

msgid "You better add"
msgstr "You better add"

msgid "to some crontab yourself with"
msgstr "to some crontab yourself with"

msgid "I replaced this old crontab line, which appears to be an older one for this same FAQ:"
msgstr "I replaced this old crontab line, which appears to be an older one for this same FAQ:"


###
### submitBag.pm
###

msgid "Bag names may only contain letters, numbers, underscores (_), hyphens (-), and periods (.), and may not end in '.desc'. Yours was"
msgstr "Bag names may only contain letters, numbers, underscores (_), hyphens (-), and periods (.), and may not end in '.desc'. Yours was"

###
### editBag.pm (OK!)
###

msgid "Replace bag"
msgstr "Korvaa liitetiedosto"

msgid "Upload new bag to show in the %0 part in <b>%1</b>."
msgstr "Lähetä uusi liitetiedosto %0. osaan kohdassa <b>%1</b>."

msgid "Bag name:"
msgstr "Liitetiedoston nimi:"

msgid "The bag name is used as a filename, so it is restricted to only contain letters, numbers, underscores (_), hyphens (-), and periods (.). It should also carry a meaningful extension (such as .gif) so that web browsers will know what to do with the data."
msgstr "Liitetiedoston nimeä käytetään tiedostonimenä, joten siinä saa olla vain kirjaimia, numeroita, alaviivoja (_), väliviivoja (-) ja pisteitä (.). Sillä pitäisi olla myös sopiva tiedoston tarkenne (kuten esimerkiksi .gif) että WWW-selaimet tietäisivät mitä tiedostolle pitäisi tehdä."

msgid "Bag data:"
msgstr "Liitetiedoston tiedot:"

msgid "(Leave blank to keep original bag data and change only the associated information below.)"
msgstr "(jätä tyhjäksi säilyttääksesi alkuperäisen liitetiedoston ja vaihtaaksesi vain muita allaolevia liitetiedostoon liittyviä tietoja.)"

msgid "If this bag is an image, fill in its dimensions."
msgstr "Jos tämä liitetiedosto on kuva, kerro sen leveys ja korkeus."

msgid "Width:"
msgstr "Leveys:"

msgid "Height:"
msgstr "Korkeus:"

###
### appearanceForm.pm (OK!)
###

msgid "Appearance Options"
msgstr "Sivun ulkonäön asetukset"

msgid "Show"
msgstr "Näytä"

msgid "Hide"
msgstr "Piilota"

msgid "all categories and answers below current category"
msgstr "kaikki ryhmät ja vastaukset nykyisen ryhmän alapuolella"

msgid "Compact"
msgstr "Tiivistetty"

msgid "expert editing commands"
msgstr "kokeneen käyttäjän muokkauskomennot"

msgid "name of moderator who organizes current category"
msgstr "nykyisen ryhmän ylläpitäjän nimi"

msgid "last modified date"
msgstr "viimeisimmän muokkauksen päivämäärä"

msgid "attributions"
msgstr "kirjoittajatiedot"

msgid "Simple"
msgstr "Yksinkertainen"

msgid "Fancy"
msgstr "Hieno"

msgid "commands for generating text output"
msgstr "tekstin muokkaamisen komennot"

msgid "Accept"
msgstr "Hyväksy"

###
### addItem.pm (OK!)
###

msgid "The file (%0) doesn't exist."
msgstr "Tiedostoa %0 ei ole olemassa."

msgid "Copy of"
msgstr "Kopio"

msgid "Subcategories:"
msgstr "Aliryhmät:"


###
### delPart.pm (OK!)
###

###
### changePass.pm (OK!)
###

msgid "Please enter your username, and select a password."
msgstr "Anna käyttäjänimesi ja valitse tunnussana."

msgid "I will send a secret number to the email address you enter to verify that it is valid."
msgstr "Lähetän tunnisteen antamaasi sähköpostiosoitteeseen varmistaakseni että osoitteesi on oikein."

msgid "If you prefer not to give your email address to this web form, please contact"
msgstr "Jos et halua antaa sähköpostiosoitettasi, ota yhteyttä"

msgid "Please <b>do not</b> use a password you use anywhere else, as it will not be transferred or stored securely!"
msgstr "<b>Älä</b> käytä tätä salasanaa missään muualla, sillä sitä ei siirretä tai talleteta tietoturvallisesti!"

msgid "Set Password"
msgstr "Aseta salasana"

###
### Auth.pm (OK!)
###

msgid "the administrator of this Faq-O-Matic"
msgstr "tämän FAQ-O-Maticin ylläpitäjä"

msgid "someone who has proven their identification"
msgstr "ne, jotka ovat antaneet tunnistetietonsa"

msgid "someone who has offered identification"
msgstr "ne, jotka ovat tarjonneet tunnistetietonsa"

msgid "anybody"
msgstr "kuka tahansa"

msgid "the moderator of the item"
msgstr "tämän tiedon ylläpitäjä"

msgid "%0 group members"
msgstr "ryhmän %0 jäsenet"

###
### Authenticate.pm (OK!)
###

msgid "Set a New Password"
msgstr "asettaa uuden salasanan"

msgid "Create a New Login"
msgstr "luoda uuden tunnuksen"

msgid "That password is invalid. If you've forgotten your old password, you can"
msgstr "Antamasi salasana ei kelpaa. Jos olet unohtanut vanhan salasanasi, voit"

msgid "New items can only be added by %0."
msgstr "Uusia tietoja voi lisätä vain %0."

msgid "New text parts can only be added by %0."
msgstr "Uusia tietoja voi lisätä vain %0."

msgid "Text parts can only be removed by %0."
msgstr "Tekstiosia voi poistaa vain %0."

msgid "This part contains raw HTML. To avoid pages with invalid HTML, the moderator has specified that only %0 can edit HTML parts. If you are %0 you may authenticate yourself with this form."
msgstr "Tämä tekstiosa sisältää HTML-koodia. Ryhmän ylläpitäjä on määrittänyt, että vain %0 voi muokata HTML-tekstiosia estääkseen virheellisen HTML:n. Jos olet %0, voit kirjoittautua sisään tämän lomakkeen avulla."

msgid "Text parts can only be added by %0."
msgstr "Uusia tekstiosia voi lisätä vain %0."

msgid "Text parts can only be edited by %0."
msgstr "Tekstiosia voi muokata vain %0."

msgid "The title and options for this item can only be edited by %0."
msgstr "Tämän tekstin otsikkoa ja asetuksia voi muuttaa ainoastaan %0."

msgid "The moderator options can only be edited by %0."
msgstr "Ylläpitäjän asetuksia voi muuttaa vain %0."

msgid "This item can only be moved by someone who can edit both the source and destination parent items."
msgstr "Tätä tietoa voivat siirtää vain ne, joilla on kirjoitusoikeus sekä lähteen että kohteen ylempiin tietoihin."

msgid "This item can only be moved by %0."
msgstr "Tätä tietoa voi siirtää vain %0."

msgid "Existing bags can only be replaced by %0."
msgstr "Olemassaolevan liitetiedoston voi korvata vain %0."

msgid "Bags can only be posted by %0."
msgstr "Liitetiedoston voi lisätä vain %0."

msgid "The FAQ-O-Matic can only be configured by %0."
msgstr "FAQ-O-Maticia voi muokata vain %0."

msgid "The operation you attempted (%0) can only be done by %1."
msgstr "Yrittämäsi tehtävä (%0) on ainoastaan %1:n tehtävissä."

msgid "If you have never established a password to use with FAQ-O-Matic, you can"
msgstr "Jos et ole koskaan luonut tunnussanaa FAQ-O-Maticiin, voit"

msgid "If you have forgotten your password, you can"
msgstr "Jos olet unohtanut salasanasi, voit"

msgid "If you have already logged in earlier today, it may be that the token I use to identify you has expired. Please log in again."
msgstr "Jos olet jo aiemmin tänään kirjautunut sisään, voi olla että tunnistetietosi on vanhentunut. Kirjaudu uudelleen sisään."

msgid "Please offer one of the following forms of identification:"
msgstr "Ole hyvä ja valitse yksi allaolevista tunnistustavoista:"

msgid "No authentication, but my email address is:"
msgstr "Ei tunnistusta, mutta sähköpostiosoitteeni on:"

msgid "Email:"
msgstr "Sähköpostiosoite:"

msgid "Authenticated login:"
msgstr "Tunnistettu sisäänkirjoittautuminen:"

msgid "Password:"
msgstr "Salasana:"

msgid "Log In"
msgstr "Kirjaudu sisään"

###
### moveItem.pm
###

msgid "Make"
msgstr "Aseta"

msgid "belong to which other item?"
msgstr "kuulumaan johonkin toiseen?"

msgid "No item that already has sub-items can become the parent of"
msgstr "No item that already has sub-items can become the parent of"

msgid "No item can become the parent of"
msgstr "No item can become the parent of"

msgid "Some destinations are not available (not clickable) because you do not have permission to edit them as currently autorized."
msgstr "Some destinations are not available (not clickable) because you do not have permission to edit them as currently autorized."

msgid "Click here</a> to provide better authentication."
msgstr "Klikkaa tästä</a> antaaksesi paremman tunnistustiedon."

msgid "Hide answers, show only categories"
msgstr "Piilota vastaukset, näytä vain ryhmät"

msgid "Show both categories and answers"
msgstr "Näytä sekä ryhmät että vastaukset"

###
### editPart.pm (OK!)
###

msgid "Enter the answer to <b>%0</b>"
msgstr "Kirjoita vastaus aiheeseen <b>%0</b>"

msgid "Enter a description for <b>%0</b>"
msgstr "Kirjoita kuvaus vastaukselle <b>%0</b>"

msgid "Edit duplicated text for <b>%0</b>"
msgstr "Muokkaa kopioitua tekstiä vastaukselle <b>%0</b>"

msgid "Enter new text for <b>%0</b>"
msgstr "Kirjoita uusi teksti vastaukselle <b>%0</b>"

msgid "Editing the %0 text part in <b>%1</b>."
msgstr "Muokataan %0. osaa vastauksessa <b>%1</b>."

msgid "If you later need to edit or delete this text, use the [Appearance] page to turn on the expert editing commands."
msgstr "Jos sinun pitää myöhemmin muokata tätä tekstiä tai poistaa se kokonaan, käytä Sivun ulkonäkö -sivua asettaaksesi päälle kokeneen käyttäjän muokkaustoiminnot."

###
### Slow.pm (OK!)
###

msgid "This page will reload every %0 seconds, showing the last %1 lines of the process output."
msgstr "Tämä sivu latautuu uudelleen joka %0. sekunti, näyttäen ohjelman tulosteesta viimeisimmät %1 riviä."

msgid "Show the entire process log"
msgstr "Näytä ohjelman koko tuloste"

###
### Part.pm (OK!)
###

msgid "Edit This Text"
msgstr "muokkaa tätä tekstiä"

msgid "Duplicate This Text"
msgstr "kopioi tämä teksti"

msgid "Remove This Text"
msgstr "poista tämä teksti"

msgid "Replace %0 with new upload"
msgstr "korvaa %0 uudella lähetettävällä tiedostolla"

msgid "Select bag to replace with new upload"
msgstr "Valitse korvattava liitetiedosto"

msgid "Upload New Bag Here"
msgstr "lähetä uusi liitetiedosto tähän"

msgid "Upload file:"
msgstr "Lähetä tiedosto:"

msgid "Warning: file contents will <b>replace</b> previous text"
msgstr "Varoitus: tiedoston sisältö <b>korvaa</b> entisen tekstin"

msgid "Hide Attributions"
msgstr "Piilota kirjoittajatiedot"

msgid "Format text as:"
msgstr "Muotoile teksti:"

msgid "Directory"
msgstr "Hakemisto"

msgid "Natural text"
msgstr "Luonnollinen teksti"

msgid "Monospaced text (code, tables)"
msgstr "Tasavälinen teksti (ohjelmakoodi, taulukot)"

msgid "Untranslated HTML"
msgstr "Muuttamaton HTML"

msgid "Answers in this category:"
msgstr "Vastaukset tässä ryhmässä:"

###
### searchForm.pm
###

msgid "search for keywords"
msgstr "etsi hakusanojen perusteella"

msgid "Search for"
msgstr "Etsi sanoja"

msgid "matching"
msgstr "ja vaadi, että löydetyillä sivuilla on"

msgid "all"
msgstr "kaikki"

msgid "any"
msgstr "mikä tahansa"

msgid "two"
msgstr "kaksi"

msgid "three"
msgstr "kolme"

msgid "four"
msgstr "neljä"

msgid "five"
msgstr "viisi"

msgid "words"
msgstr "hakusana(a/t)"

msgid "search for recent changes"
msgstr "etsi lähiaikoina muokattuja tietoja"

msgid "Show documents"
msgstr "Näytä vastaukset"

msgid "modified in the last"
msgstr "joita on muokattu viimeisen"

msgid "day"
msgstr "päivän aikana"

msgid "two days"
msgstr "kahden päivän aikana"

msgid "three days"
msgstr "kolmen päivän aikana"

msgid "week"
msgstr "viikon aikana"

msgid "fortnight"
msgstr "kahden viikon aikana"

msgid "month"
msgstr "kuukauden aikana"

###
### search.pm
###

msgid "No items matched"
msgstr "Ei osumia"

msgid "of these words"
msgstr "näistä sanoista"

msgid "Search results for"
msgstr "Haun tulokset hakuehdolle"

msgid "at least"
msgstr "vähintään"

msgid "Results may be incomplete, because the search index has not been refreshed since the most recent change to the database."
msgstr "Tuloslista voi olla epätäydellinen, sillä tietokantaa on muutettu hakuindeksin luomisen jälkeen."

###
### Item.pm (OK!)
###

msgid "New Item"
msgstr "Uusi asia"

msgid "Parts"
msgstr "Osat"

msgid "Previous"
msgstr "Edellinen"

msgid "Next"
msgstr "Seuraava"

msgid "Moderator"
msgstr "Ylläpitäjä"

msgid "(inherited from parent)"
msgstr "(peritty ylemmältä tasolta)"

msgid "%0 Title and Options"
msgstr "%0n otsikko ja asetukset"

msgid "Edit %0 Permissions"
msgstr "muokkaa %0n oikeuksia"

msgid "Duplicate Answer"
msgstr "kopioi vastaus"

msgid "Duplicate Category as Answer"
msgstr "kopioi ryhmä vastaukseksi"

msgid "Move %0"
msgstr "siirrä %0"

msgid "Trash %0"
msgstr "poista %0"

msgid "Convert to Answer"
msgstr "muunna vastaukseksi"

msgid "Convert to Category"
msgstr "muunna ryhmäksi"

msgid "New Answer in %0"
msgstr "lisää uusi vastaus ryhmään %0"

msgid "New Subcategory of"
msgstr "uusi alaryhmä ryhmälle"

msgid "Insert Text Here"
msgstr "lisää teksti tähän"

msgid "Insert Uploaded Text Here"
msgstr "lisää lähetetty teksti tähän"

msgid "Append to This Answer"
msgstr "Lisää tähän vastaukseen"

msgid "This document is:"
msgstr "Tämän sivun osoite on:"

msgid "This document is at:"
msgstr "Tämä teksti on osoitteessa:"

msgid "Inherit"
msgstr "Peritään"

msgid "Group %0"
msgstr "Käyttäjäryhmä %0"

msgid "Users giving their names"
msgstr "Käyttäjät jotka kertovat nimensä"

msgid "Authenticated users"
msgstr "Tunnistetut käyttäjät"

msgid "Whoever can for my parent,"
msgstr "Kuka tahansa joka voi tehdä saman ylemmälle tasollekin,"

msgid "New Category"
msgstr "uusi ryhmä"

msgid "New Answer"
msgstr "uusi vastaus"

msgid "Editing %0 <b>%1</b>"
msgstr "Muokataan kohdetta <b>%1</b>" ## FIXME

msgid "Title:"
msgstr "Otsikko:"

msgid "<p>New Order for Text Parts:"
msgstr "<p>Uusi osien järjestys:"

msgid "Show attributions from all parts together at bottom"
msgstr "Näytä kirjoittajatiedot kaikista osista yhdessä sivun alalaidassa"

msgid "Submit Changes"
msgstr "Tallenna muutokset"

msgid "Revert"
msgstr "Palauta"
 
msgid "Who can add a new text part to this item:"
msgstr "Kuka voi lisätä tekstiosia tähän tekstiin:"

msgid "Who can add a new answer or category to this category:"
msgstr "Kuka voi lisätä uuden vastauksen tai ryhmän tähän ryhmään:"

msgid "Who can edit or remove existing text parts from this item:"
msgstr "Kuka voi muokata tai poistaa olemassaolevia tekstiosia:"

msgid "Who can move answers or subcategories from this category;"
msgstr "Kuka voi siirtää vastauksia tai aliryhmiä tästä ryhmästä;"

msgid "Who can edit the title and options of this answer or category:"
msgstr "Kuka voi muokata tämän ryhmän tai vastauksen otsikkoa ja asetuksia:"

msgid "Who can use untranslated HTML when editing the text of"
msgstr "Kuka saa käyttää muuttamatonta HTML-koodia muokatessaan tekstiä kohdasta"

msgid "Who can change these moderator options and permissions:"
msgstr "Kuka voi vaihtaa näitä ylläpidon asetuksia ja oikeuksia:"

msgid "Who can create new bags:"
msgstr "Kuka voi luoda uusia liitetiedostoja:"

msgid "Who can replace existing bags:"
msgstr "Kuka voi korvata olemassaolevia liitetiedostoja:"

msgid "Who can access the installation/configuration page (use caution!):"
msgstr "Kuka pääsee asennus- ja asetussivulle (käytä varoen!):"

msgid "Who can use the group membership pages:"
msgstr "Kuka voi määritellä käyttäjäryhmiä:"

msgid "Moderator options for"
msgstr "Valvojan asetukset kohteelle"

msgid "Name & Description"
msgstr "Nimi ja kuvaus"

msgid "Setting"
msgstr "Asetus"

msgid "Setting if Inherited"
msgstr "Käytettävä asetus jos peritty"

msgid "(will inherit if empty)"
msgstr "(peritään jos tyhjä)"

msgid "Send mail to the moderator when someone other than the moderator edits this item:"
msgstr "Lähetä postia ylläpitäjälle kun joku muu kuin ylläpitäjä muokkaa tätä tietoa:"

msgid "Yes"
msgstr "Kyllä"

msgid "No"
msgstr "Ei"

msgid "undefined"
msgstr "määrittelemättä"

msgid "Permissions"
msgstr "oikeudet"  ##FIXME oikeuksia?

msgid "Blah blah"
msgstr "Päläpälä"

msgid "Relax"
msgstr "Vapauta"

msgid "Don't Relax"
msgstr "Älä vapauta"

msgid "(system default)"
msgstr "(järjestelmän oletusarvo)"

msgid "defined in"
msgstr "määritelty"

msgid "File %0 seems broken."
msgstr "Tiedosto %0 näyttää olevan rikki."

msgid "Either someone has changed the answer or category you were editing since you received the editing form, or you submitted the same form twice"
msgstr "Joko joku muu on muuttanut muokkaamaasi kohdetta sillä välin kun itse muokkasit sitä, tai lähetit samat muutokset kahteen kertaan"

msgid "Please %0 and start again to make sure no changes are lost. Sorry for the inconvenience."
msgstr "Ole hyvä ja %0 ja aloita uudelleen alusta varmistaaksesi ettei muutoksia ole kadonnut. Valitan hankaluutta."

msgid "(Sequence number in form: %0; in item: %1)"
msgstr "(Järjestysnumero lomakkeessa: %0; tiedostossa: %1)"

###
### Appearance.pm (OK!)
###

msgid "Search"
msgstr "etsi"

msgid "Appearance"
msgstr "sivun ulkonäkö"

msgid "Show Top Category Only"
msgstr "näytä vain ylin ryhmä"

msgid "Show This <em>Entire</em> Category"
msgstr "näytä tämä <em>koko</em> ryhmä aliryhmineen"

msgid "Show This %0 As Text"
msgstr "näytä tämä %0 tekstinä"

msgid "Show This <em>Entire</em> Category As Text"
msgstr "näytä tämä <em>koko</em> ryhmä tekstinä aliryhmineen"

msgid "Hide Expert Edit Commands"
msgstr "piilota kokeneen käyttäjän muokkaustoiminnot"

msgid "Show Expert Edit Commands"
msgstr "näytä kokeneen käyttäjän muokkaustoiminnot"

msgid "Return to the FAQ"
msgstr "palaa usein kysyttyihin kysymyksiin"

msgid "This is a"
msgstr "Tämä on"
);
__EOF__

	my @txs = grep { m/^msg/ } split(/\n/, $txfile);
	for (my $i=0; $i<@txs; $i+=2) {
		$txs[$i] =~ m/msgid \"(.*)\"$/;
		my $from = $1;
		$txs[$i+1] =~ m/msgstr \"(.*)\"$/;
		my $to = $1;
		if (not defined $from or not defined $to) {
			die "bad translation at pair $i ("
				.$txs[$i]
				."=>"
				.$txs[$i+1]
				.")";
		}
		$tx->{$from} = $to;
	}
};
