#--------------------------------------------------------------------
#   Language_ja_JP.EUC.pm
#   Generated automatically from ja.po by po2pm
#--------------------------------------------------------------------

sub translations {
    my $tx = shift;

    my %data = (

# SOME DESCRIPTIVE TITLE.
# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
# This file is distributed under the same license as the PACKAGE package.
# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
#
#, fuzzy
 ""
# fuzzy # => "Project-Id-Version: PACKAGE VERSION\nPOT-Creation-Date: 2003-03-23 08:01+0900\nPO-Revision-Date: 2002-12-05 23:20+0900\nLast-Translator: Oota Toshiya <oota@itp.nec.co.jp>\nLanguage-Team: Japanese\nMIME-Version: 1.0\nContent-Type: text/plain; charset=EUC-JP\nContent-Transfer-Encoding: 8bit\n",
 => "",

#: lib/FAQ/OMatic.pm:96 lib/FAQ/OMatic/install.pm:1079
 "Warnings:"
 => "警告:",

#: lib/FAQ/OMatic.pm:111
#, fuzzy
 "Your Faq-O-Matic would have a title if it had an item 1, which it will when you've run the installer."
# fuzzy # => "アイテム1が存在するならば、あなたのFaq-O-Maticは",
 => "",

#: lib/FAQ/OMatic.pm:114 lib/FAQ/OMatic/install.pm:1164
 "Untitled Faq-O-Matic"
 => "未タイトルの Faq-O-Matic",

#: lib/FAQ/OMatic.pm:136 lib/FAQ/OMatic/authenticate.pm:151
 "Log In"
 => "ログイン",

#: lib/FAQ/OMatic.pm:137
 "Change Password"
 => "パスワード変更",

#: lib/FAQ/OMatic.pm:138
 "Edit Title of %0 %1"
 => "%0のタイトル %1 を編集",

#: lib/FAQ/OMatic.pm:139
#, c-format
 "New %0"
 => "新規 %0\t",

#: lib/FAQ/OMatic.pm:140
 "Edit Part in %0 %1"
 => "%0 中のパート %1 を編集",

#: lib/FAQ/OMatic.pm:141
 "Insert Part in %0 %1"
 => "%0 中に %1 を挿入",

#: lib/FAQ/OMatic.pm:142
 "Move %0 %1"
 => "%0 を %1 に移動",

#: lib/FAQ/OMatic.pm:143 lib/FAQ/OMatic/Appearance.pm:168
 "Search"
 => "検索",

#: lib/FAQ/OMatic.pm:144
 "Access Statistics"
 => "アクセス統計",

#: lib/FAQ/OMatic.pm:145 lib/FAQ/OMatic/submitPass.pm:138
 "Validate"
 => "認証",

#: lib/FAQ/OMatic.pm:146
 "%0 Permissions for %1"
 => "%1のパーミッションを %0",

#: lib/FAQ/OMatic.pm:147
 "Upload bag for %0 %1"
 => "%0 向けのbagのアップロード %1",

#: lib/FAQ/OMatic.pm:1663
 "http-charset"
 => "EUC-JP",

#: lib/FAQ/OMatic/Appearance.pm:177
 "Appearance"
 => "見た目",

#: lib/FAQ/OMatic/Appearance.pm:191
 "Show Top Category Only"
 => "トップカテゴリのみ表示",

#: lib/FAQ/OMatic/Appearance.pm:198
 "Show This <em>Entire</em> Category"
 => "この<em>全部の</em> カテゴリを表示",

#: lib/FAQ/OMatic/Appearance.pm:209
 "Show This Category As Text"
 => "このカテゴリをテキストとして表示",

#: lib/FAQ/OMatic/Appearance.pm:213
 "Show This Answer As Text"
 => "この回答をテキストとして表示",

#: lib/FAQ/OMatic/Appearance.pm:218
 "Show This %0 As Text"
 => "%0 をテキストとして表示",

#: lib/FAQ/OMatic/Appearance.pm:232
 "Show This <em>Entire</em> Category As Text"
 => "この<em>全部の</em> カテゴリをテキストとして表示",

#: lib/FAQ/OMatic/Appearance.pm:244
 "Hide Expert Edit Commands"
 => "上級編集コマンドを隠す",

#: lib/FAQ/OMatic/Appearance.pm:253
 "Show Expert Edit Commands"
 => "上級編集コマンドを表示",

#: lib/FAQ/OMatic/Appearance.pm:269 lib/FAQ/OMatic/Item.pm:2224
#: lib/FAQ/OMatic/stats.pm:133
 "Return to the FAQ"
 => "FAQに戻る",

#: lib/FAQ/OMatic/Appearance.pm:276
 "This is a"
 => "これは",

#: lib/FAQ/OMatic/Auth.pm:495
 "the administrator of this Faq-O-Matic"
 => "FAQ-O-Maticの管理者",

#: lib/FAQ/OMatic/Auth.pm:496
 "someone who has proven their identification"
 => "だれかがかれらの識別を検査した",

#: lib/FAQ/OMatic/Auth.pm:497
 "someone who has offered identification"
 => "だれかが識別子を提供した",

#: lib/FAQ/OMatic/Auth.pm:498
 "anybody"
 => "全員",

#: lib/FAQ/OMatic/Auth.pm:511
 "the moderator of the item"
 => "このアイテムのモデレータ",

#: lib/FAQ/OMatic/Auth.pm:515
#, c-format
 "%0 group members"
 => "グループメンバー %0",

#: lib/FAQ/OMatic/Groups.pm:142
 "Select a group to edit:"
 => "編集対象のグループを選択:",

#: lib/FAQ/OMatic/Groups.pm:150
 "(Members of this group are allowed to access these group definition pages.)"
 => "(グループのメンバはそのグループ定義ページにアクセスできる。)",

#: lib/FAQ/OMatic/Groups.pm:168
 "Add Group"
 => "グループ追加",

#: lib/FAQ/OMatic/Groups.pm:175
 "Up To List Of Groups"
 => "グループのリストの上へ",

#: lib/FAQ/OMatic/Groups.pm:187
 "Remove Member"
 => "メンバ削除",

#: lib/FAQ/OMatic/Groups.pm:196
 "Add Member"
 => "メンバ追加",

#: lib/FAQ/OMatic/Groups.pm:206 lib/FAQ/OMatic/install.pm:467
#: lib/FAQ/OMatic/install.pm:471
 "Go to the Faq-O-Matic"
 => "Faq-O-Maticに移動",

#: lib/FAQ/OMatic/Groups.pm:209 lib/FAQ/OMatic/maintenance.pm:134
 "Go To Install/Configuration Page"
 => "インストール/構成ページに移動",

#: lib/FAQ/OMatic/Item.pm:83
 "New Item"
 => "新しいアイテム",

#: lib/FAQ/OMatic/Item.pm:727
 "Parts"
 => "パート",

#: lib/FAQ/OMatic/Item.pm:750
 "(missing or broken file)"
 => "(不明または壊れたファイル)",

#: lib/FAQ/OMatic/Item.pm:851
 "Previous"
 => "前",

#: lib/FAQ/OMatic/Item.pm:869
 "Next"
 => "次",

#: lib/FAQ/OMatic/Item.pm:968 lib/FAQ/OMatic/Item.pm:1382
#: lib/FAQ/OMatic/Item.pm:1566
 "Moderator"
 => "モデレータ",

#: lib/FAQ/OMatic/Item.pm:970
 "(inherited from parent)"
 => "(親から継承)",

#: lib/FAQ/OMatic/Item.pm:988
 "Category Title and Options"
 => "カテゴリのタイトルとオプション",

#: lib/FAQ/OMatic/Item.pm:989
 "Edit Category Permissions"
 => "カテゴリのパーミッションを編集",

#: lib/FAQ/OMatic/Item.pm:990
 "Move Category"
 => "カテゴリを移動",

#: lib/FAQ/OMatic/Item.pm:991
 "Trash Category"
 => "カテゴリを廃棄",

#: lib/FAQ/OMatic/Item.pm:995
 "Answer Title and Options"
 => "回答のタイトルとオプション",

#: lib/FAQ/OMatic/Item.pm:996
 "Edit Answer Permissions"
 => "回答のパーミッションを編集",

#: lib/FAQ/OMatic/Item.pm:997
 "Move Answer"
 => "回答を移動",

#: lib/FAQ/OMatic/Item.pm:998
 "Trash Answer"
 => "回答を廃棄",

#: lib/FAQ/OMatic/Item.pm:1004
 "%0 Title and Options"
 => "%0 タイトルとオプション",

#: lib/FAQ/OMatic/Item.pm:1005 lib/FAQ/OMatic/Item.pm:1006
 "Edit %0 Permissions"
 => "%0 のパーミッションを編集",

#: lib/FAQ/OMatic/Item.pm:1007
#, c-format
 "Move %0"
 => "%0 を移動",

#: lib/FAQ/OMatic/Item.pm:1008
#, c-format
 "Trash %0"
 => "%0 を廃棄",

#: lib/FAQ/OMatic/Item.pm:1046
 "Duplicate Answer"
 => "回答の複製",

#: lib/FAQ/OMatic/Item.pm:1047
 "Duplicate Category as Answer"
 => "回答としてカテゴリを複製",

#: lib/FAQ/OMatic/Item.pm:1090
 "Convert to Answer"
 => "回答に変換",

#: lib/FAQ/OMatic/Item.pm:1100
 "Convert to Category"
 => "カテゴリに変換",

#: lib/FAQ/OMatic/Item.pm:1116 lib/FAQ/OMatic/Item.pm:1196
 "New Answer in \"%0\""
 => "\"%0\"中の新しい回答",

#: lib/FAQ/OMatic/Item.pm:1123
 "New Subcategory of \"%0\""
 => "\"%0\"の中の新しいサブカテゴリ",

#: lib/FAQ/OMatic/Item.pm:1149 lib/FAQ/OMatic/Part.pm:346
 "Insert Text Here"
 => "ここにテキストを挿入",

#: lib/FAQ/OMatic/Item.pm:1162 lib/FAQ/OMatic/Part.pm:357
 "Insert Uploaded Text Here"
 => "アップロードするテキストをここに挿入",

#: lib/FAQ/OMatic/Item.pm:1212
 "Append to This Answer"
 => "この答に追加",

#: lib/FAQ/OMatic/Item.pm:1330
 "This document is:"
 => "このドキュメントは:",

#: lib/FAQ/OMatic/Item.pm:1332
 "This document is at:"
 => "このドキュメントのURLは:",

#: lib/FAQ/OMatic/Item.pm:1376
#, c-format
 "Group %0"
 => "グループ %0",

#: lib/FAQ/OMatic/Item.pm:1380
 "Users giving their names"
 => "ユーザはユーザ名を与えた",

#: lib/FAQ/OMatic/Item.pm:1381
 "Authenticated users"
 => "認証されたユーザ",

#: lib/FAQ/OMatic/Item.pm:1396
 "New Category"
 => "新規カテゴリ",

#: lib/FAQ/OMatic/Item.pm:1398
 "New Answer"
 => "新しい回答",

#: lib/FAQ/OMatic/Item.pm:1402
 "Editing Category <b>%0</b>"
 => "カテゴリを編集 <b>%0</b>",

#: lib/FAQ/OMatic/Item.pm:1406
 "Editing Answer <b>%0</b>"
 => "回答を編集 <b>%0</b>",

#: lib/FAQ/OMatic/Item.pm:1411
 "Editing %0 <b>%1</b>"
 => "カテゴリ編集 <b>%0</b>",

#: lib/FAQ/OMatic/Item.pm:1441
 "Title:"
 => "タイトル:",

#: lib/FAQ/OMatic/Item.pm:1446
 "<p>New Order for Text Parts:"
 => "<p>テキストパートの新しい順番:",

#: lib/FAQ/OMatic/Item.pm:1458
 "Show attributions from all parts together at bottom"
 => "すべてのパートからの属性を最下部に一緒に表示",

#: lib/FAQ/OMatic/Item.pm:1471 lib/FAQ/OMatic/Item.pm:1667
#: lib/FAQ/OMatic/Part.pm:560 lib/FAQ/OMatic/editBag.pm:122
 "Submit Changes"
 => "変更の送信",

#: lib/FAQ/OMatic/Item.pm:1472 lib/FAQ/OMatic/Item.pm:1668
#: lib/FAQ/OMatic/Part.pm:561 lib/FAQ/OMatic/editBag.pm:123
 "Revert"
 => "復帰",

#: lib/FAQ/OMatic/Item.pm:1492
 "Who can add a new text part to this item:"
 => "このアイテムに新しいパートを追加できる人:",

#: lib/FAQ/OMatic/Item.pm:1494
 "Who can add a new answer or category to this category:"
 => "このカテゴリに新しい答かカテゴリを追加できる人:",

#: lib/FAQ/OMatic/Item.pm:1496
 "Who can edit or remove existing text parts from this item:"
 => "このアイテムから存在するテキストパートを編集又は削除できる人:",

#: lib/FAQ/OMatic/Item.pm:1498
 "Who can move answers or subcategories from this category; or turn this category into an answer or vice versa:"
 => "このカテゴリから回答又はサブカテゴリを移動できる人;又はこのカテゴリを回答又は何かに変更する:",

#: lib/FAQ/OMatic/Item.pm:1500
 "Who can edit the title and options of this answer or category:"
 => "この回答かカテゴリのタイトルとオプションを編集できる人:",

#: lib/FAQ/OMatic/Item.pm:1502
 "Who can use untranslated HTML when editing the text of this answer or category:"
 => "この回答かカテゴリのテキストを編集する時に変換無しのHTMLを使える人:",

#: lib/FAQ/OMatic/Item.pm:1504
 "Who can change these moderator options and permissions:"
 => "モデレータオプションとパーミッションを変更できる人:",

#: lib/FAQ/OMatic/Item.pm:1506
 "Who can create new bags:"
 => "新しいbagを作れる人:",

#: lib/FAQ/OMatic/Item.pm:1508
 "Who can replace existing bags:"
 => "存在する袋を置換できる人:",

#: lib/FAQ/OMatic/Item.pm:1510
 "Who can access the installation/configuration page (use caution!):"
 => "インストール/構成ページにアクセスできる人(使用注意!):",

#: lib/FAQ/OMatic/Item.pm:1512
 "Who can use the group membership pages:"
 => "グループメンバシップページを使える人:",

#: lib/FAQ/OMatic/Item.pm:1529
 "Moderator options for category"
 => "カテゴリのためのモデレータオプション",

#: lib/FAQ/OMatic/Item.pm:1533
 "Moderator options for answer"
 => "回答のためのモデレータオプション",

#: lib/FAQ/OMatic/Item.pm:1538
 "Moderator options for"
 => "右記の項目のためのモデレータオプション ",

#: lib/FAQ/OMatic/Item.pm:1556
 "Name & Description"
 => "名前と説明",

#: lib/FAQ/OMatic/Item.pm:1557
 "Setting"
 => "設定",

#: lib/FAQ/OMatic/Item.pm:1558
 "Setting if Inherited"
 => "継承していた場合の設定",

#: lib/FAQ/OMatic/Item.pm:1567 lib/FAQ/OMatic/Item.pm:1604
 "(will inherit if empty)"
 => "(もしも空白ならば継承される)",

#: lib/FAQ/OMatic/Item.pm:1577
 "Send mail to the moderator when someone other than the moderator edits this item:"
 => "モデレータ以外のだれかがこのアイテムを編集した時にメールをモデレータに送る:",

#: lib/FAQ/OMatic/Item.pm:1583 lib/FAQ/OMatic/Item.pm:1620
 "No"
 => "いいえ",

#: lib/FAQ/OMatic/Item.pm:1583 lib/FAQ/OMatic/Item.pm:1620
 "Yes"
 => "はい",

#: lib/FAQ/OMatic/Item.pm:1583 lib/FAQ/OMatic/Item.pm:1620
#: lib/FAQ/OMatic/Item.pm:1661
 "undefined"
 => "未定義",

#: lib/FAQ/OMatic/Item.pm:1602
 "Notifier"
 => "通知先",

#: lib/FAQ/OMatic/Item.pm:1603
 "Send mail to the Notifier when item is created or modified"
 => "アイテムが作成又は変更された時にメールを通知先に送る",

#: lib/FAQ/OMatic/Item.pm:1614
 "Send mail to the Notifier when someone other than the moderator edits this item:"
 => "モデレータ以外のだれかがこのアイテムを編集した時にメールをモデレータに送る:",

#: lib/FAQ/OMatic/Item.pm:1625
 "Permissions"
 => "パーミッション",

#: lib/FAQ/OMatic/Item.pm:1647
 "Relax: New answers and subcategories will be moderated "
 => "緩和: 新しい回答とサブカテゴリは、その新しいアイテムを編集",

#: lib/FAQ/OMatic/Item.pm:1648
 "by the creator of the item, allowing that person full "
 => "するための完全な自由を人々に許可することをアイテムの作者によって",

#: lib/FAQ/OMatic/Item.pm:1649
 "freedom to edit that new item."
 => "モデレートされる。",

#: lib/FAQ/OMatic/Item.pm:1650
 "Don't Relax: new items will be moderated by "
 => "緩和しない: 新しいアイテムは、このアイテムの",

#: lib/FAQ/OMatic/Item.pm:1651
 "the moderator of this item."
 => "モデレータによってモデレートされる。",

#: lib/FAQ/OMatic/Item.pm:1656 lib/FAQ/OMatic/Item.pm:1660
 "Relax"
 => "緩和",

#: lib/FAQ/OMatic/Item.pm:1656 lib/FAQ/OMatic/Item.pm:1660
 "Don't Relax"
 => "緩和しない",

#: lib/FAQ/OMatic/Item.pm:1656
 "Inherit"
 => "|継承|",

#: lib/FAQ/OMatic/Item.pm:1690 lib/FAQ/OMatic/Item.pm:1704
 "(system default)"
 => "(システム既定値)",

#: lib/FAQ/OMatic/Item.pm:1696
 "defined in"
 => "右記で定義",

#: lib/FAQ/OMatic/Item.pm:1775
#, c-format
 "File %0 seems broken."
 => "ファイル %0 が壊れているように見える。",

#: lib/FAQ/OMatic/Item.pm:2155
 "Category"
 => "カテゴリ",

#: lib/FAQ/OMatic/Item.pm:2156
 "Answer"
 => "回答",

#: lib/FAQ/OMatic/Item.pm:2226
 "Either someone has changed the answer or category you were editing since you received the editing form, or you submitted the same form twice."
 => "だれかが編集フォームを受け取ってから回答又はカテゴリを変更したか、フォームを二回送信した",

#: lib/FAQ/OMatic/Item.pm:2228
 "Please %0 and start again to make sure no changes are lost. Sorry for the inconvenience."
 => "%0 と変更しない分が失われないように、再度スタート。不便を詫びる。",

#: lib/FAQ/OMatic/Item.pm:2231
 "(Sequence number in form: %0; in item: %1)"
 => "(アイテム %1 中のフォーム: %0 のシーケンス番号)",

#: lib/FAQ/OMatic/Part.pm:270
 "Edit This Text"
 => "このテキストを編集",

#: lib/FAQ/OMatic/Part.pm:281
 "Duplicate This Text"
 => "このテキストを複製",

#: lib/FAQ/OMatic/Part.pm:292 lib/FAQ/OMatic/Part.pm:305
 "Remove This Text"
 => "このテキストを削除",

#: lib/FAQ/OMatic/Part.pm:317
 "Replace %0 with new upload"
 => "%0 を新しいアップロードしたもので置換",

#: lib/FAQ/OMatic/Part.pm:324
 "Select bag to replace with new upload"
 => "アップロードで置換するbagを選択",

#: lib/FAQ/OMatic/Part.pm:333
 "Upload New Bag Here"
 => "新しいbagをここにアップロード",

#: lib/FAQ/OMatic/Part.pm:498
 "Upload file:"
 => "ファイルをアップロード:",

#: lib/FAQ/OMatic/Part.pm:503
 "Warning: file contents will <b>replace</b> previous text"
 => "警告: ファイルの内容は以前のテキストで <b>置換</b> ",

#: lib/FAQ/OMatic/Part.pm:510
 "Hide Attributions"
 => "属性を隠す",

#: lib/FAQ/OMatic/Part.pm:513
 "Format text as:"
 => "書式テキストは:",

#: lib/FAQ/OMatic/Part.pm:523
 "Directory"
 => "ディレクトリ",

#: lib/FAQ/OMatic/Part.pm:530
 "Natural text"
 => "自然なテキスト",

#: lib/FAQ/OMatic/Part.pm:534
 "Monospaced text (code, tables)"
 => "1つのスペースのテキストText (コード,テーブル)",

#: lib/FAQ/OMatic/Part.pm:549
 "Untranslated HTML"
 => "変換されないHTML",

#: lib/FAQ/OMatic/Part.pm:699 lib/FAQ/OMatic/addItem.pm:102
#: lib/FAQ/OMatic/install.pm:1177 lib/FAQ/OMatic/submitAnsToCat.pm:67
 "Answers in this category:"
 => "このカテゴリの回答",

#: lib/FAQ/OMatic/SearchMod.pm:293
 "zero days"
 => "0日",

#: lib/FAQ/OMatic/SearchMod.pm:294
 "day"
 => "日",

#: lib/FAQ/OMatic/SearchMod.pm:295
 "two days"
 => "2日",

#: lib/FAQ/OMatic/SearchMod.pm:296
 "week"
 => "週",

#: lib/FAQ/OMatic/SearchMod.pm:297
 "fortnight"
 => "二週間",

#: lib/FAQ/OMatic/SearchMod.pm:298
 "month"
 => "月",

#: lib/FAQ/OMatic/SearchMod.pm:299
 "three months"
 => "3ヶ月",

#: lib/FAQ/OMatic/SearchMod.pm:300
 "six months"
 => "6ヶ月",

#: lib/FAQ/OMatic/SearchMod.pm:301
 "year"
 => "年",

#: lib/FAQ/OMatic/SearchMod.pm:314
 "days"
 => "日",

#: lib/FAQ/OMatic/Slow.pm:138
#, c-format
 "This page will reload every %0 seconds,"
 => "このページは毎 %0 秒ごとにリロードされ、",

#: lib/FAQ/OMatic/Slow.pm:141
 "showing the entire process output."
 => "プロセスの出力の全部を表示する。",

#: lib/FAQ/OMatic/Slow.pm:142
 "Show the tail of the process log"
 => "プロセスログの末尾を表示",

#: lib/FAQ/OMatic/Slow.pm:144
#, c-format
 "showing the last %0 lines of the process output."
 => "プロセス出力の最後の %0 行を表示する。",

#: lib/FAQ/OMatic/Slow.pm:145
 "Show the entire process log"
 => "全てのプロセスログを表示",

#: lib/FAQ/OMatic/addItem.pm:48 lib/FAQ/OMatic/delPart.pm:47
#: lib/FAQ/OMatic/editItem.pm:50 lib/FAQ/OMatic/editModOptions.pm:50
#: lib/FAQ/OMatic/faq.pm:74 lib/FAQ/OMatic/moveItem.pm:50
#: lib/FAQ/OMatic/selectBag.pm:60 lib/FAQ/OMatic/submitAnsToCat.pm:49
#: lib/FAQ/OMatic/submitCatToAns.pm:48 lib/FAQ/OMatic/submitItem.pm:48
#: lib/FAQ/OMatic/submitModOptions.pm:47 lib/FAQ/OMatic/submitPart.pm:48
 "The file (%0) doesn't exist."
 => "ファイル (%0) が存在しない。",

#: lib/FAQ/OMatic/addItem.pm:67
 "Copy of"
 => "→のコピー",

#: lib/FAQ/OMatic/addItem.pm:102 lib/FAQ/OMatic/install.pm:1177
#: lib/FAQ/OMatic/submitAnsToCat.pm:67
 "Subcategories:"
 => "サブカテゴリ:",

#: lib/FAQ/OMatic/appearanceForm.pm:46
 "Appearance Options"
 => "見た目オプション",

#: lib/FAQ/OMatic/appearanceForm.pm:60 lib/FAQ/OMatic/appearanceForm.pm:64
#: lib/FAQ/OMatic/appearanceForm.pm:68 lib/FAQ/OMatic/appearanceForm.pm:84
#: lib/FAQ/OMatic/appearanceForm.pm:92
 "Show"
 => "表示",

#: lib/FAQ/OMatic/appearanceForm.pm:60
 "Compact"
 => "縮小",

#: lib/FAQ/OMatic/appearanceForm.pm:60 lib/FAQ/OMatic/appearanceForm.pm:64
#: lib/FAQ/OMatic/appearanceForm.pm:68 lib/FAQ/OMatic/appearanceForm.pm:84
#: lib/FAQ/OMatic/appearanceForm.pm:92
 "Hide"
 => "非表示",

#: lib/FAQ/OMatic/appearanceForm.pm:62 lib/FAQ/OMatic/install.pm:803
 "expert editing commands"
 => "上級向け編集コマンド",

#: lib/FAQ/OMatic/appearanceForm.pm:66 lib/FAQ/OMatic/install.pm:808
 "name of moderator who organizes current category"
 => "現在のカテゴリを管理するモデレータ名",

#: lib/FAQ/OMatic/appearanceForm.pm:70 lib/FAQ/OMatic/install.pm:813
 "last modified date"
 => "最後に変更した日時",

#: lib/FAQ/OMatic/appearanceForm.pm:84
 "Default"
 => "既定値",

#: lib/FAQ/OMatic/appearanceForm.pm:86 lib/FAQ/OMatic/install.pm:818
 "attributions"
 => "属性",

#: lib/FAQ/OMatic/appearanceForm.pm:88
 "Simple"
 => "単純",

#: lib/FAQ/OMatic/appearanceForm.pm:88
 "Fancy"
 => "きれい",

#: lib/FAQ/OMatic/appearanceForm.pm:94 lib/FAQ/OMatic/install.pm:823
 "commands for generating text output"
 => "テキスト出力作成のためのコマンド",

#: lib/FAQ/OMatic/appearanceForm.pm:126
 "Accept"
 => "許可",

#: lib/FAQ/OMatic/authenticate.pm:55
 "Set a New Password"
 => "新しいパスワードを設定",

#: lib/FAQ/OMatic/authenticate.pm:60
 "Create a New Login"
 => "新しいログインを作成",

#: lib/FAQ/OMatic/authenticate.pm:63
 "That password is invalid. If you've forgotten your old password, you can"
 => "そのパスワードは不正。もしもパスワードを忘れたら、",

#: lib/FAQ/OMatic/authenticate.pm:81
#, c-format
 "New items can only be added by %0."
 => "新しいアイテムは %0 のみ追加できる。",

#: lib/FAQ/OMatic/authenticate.pm:83
#, c-format
 "New text parts can only be added by %0."
 => "新しいテキストパートは %0 のみ追加できる。",

#: lib/FAQ/OMatic/authenticate.pm:85
#, c-format
 "Text parts can only be removed by %0."
 => "テキストパートは %0 のみ削除できる。",

#: lib/FAQ/OMatic/authenticate.pm:89
 "This part contains raw HTML. To avoid pages with invalid HTML, the moderator has specified that only %0 can edit HTML parts. If you are %0 you may authenticate yourself with this form."
 => "このパートは生のHTMLを含んでいる。不正なHTMLを含むページを防止するため、モデレータは %0 のみが編集出来るように指定している。もしも %0 ならば、このフォームで自分自身を認証する必要がある。",

#: lib/FAQ/OMatic/authenticate.pm:91
#, c-format
 "Text parts can only be added by %0."
 => "テキストパートは %0 のみ追加できる。",

#: lib/FAQ/OMatic/authenticate.pm:93
#, c-format
 "Text parts can only be edited by %0."
 => "テキストパートは %0 のみ編集できる。",

#: lib/FAQ/OMatic/authenticate.pm:96
#, c-format
 "The title and options for this item can only be edited by %0."
 => "このアイテムのタイトルとオプションは %0 のみ編集できる。",

#: lib/FAQ/OMatic/authenticate.pm:98
#, c-format
 "The moderator options can only be edited by %0."
 => "モデレータオプションは %0 のみ編集できる。",

#: lib/FAQ/OMatic/authenticate.pm:101
 "This item can only be moved by someone who can edit both the source and destination parent items."
 => "このアイテムはソースとディストネーション親アイテム両方を編集できる人のみが移動できる。",

#: lib/FAQ/OMatic/authenticate.pm:103
#, c-format
 "This item can only be moved by %0."
 => "このアイテムは %0 のみ移動できる。",

#: lib/FAQ/OMatic/authenticate.pm:110
#, c-format
 "Existing bags can only be replaced by %0."
 => "存在するbagは %0 のみ更新できる。",

#: lib/FAQ/OMatic/authenticate.pm:112
#, c-format
 "Bags can only be posted by %0."
 => "bagは %0 のみ投稿できる。",

#: lib/FAQ/OMatic/authenticate.pm:115
#, c-format
 "The FAQ-O-Matic can only be configured by %0."
 => "FAQ-O-Matic は %0 のみ構成できる。",

#: lib/FAQ/OMatic/authenticate.pm:117
 "The operation you attempted (%0) can only be done by %1."
 => "(%0) に対して試みた操作は %1 によってのみ完了できる。",

#: lib/FAQ/OMatic/authenticate.pm:120
 "If you have never established a password to use with FAQ-O-Matic, you can"
 => "もしも、FAQ-O-Matic 用のパスワードを確立していないならば、右記でログイン",

#: lib/FAQ/OMatic/authenticate.pm:121
 "If you have forgotten your password, you can"
 => "もしも、パスワードを忘れたら右記で新規パスワード",

#: lib/FAQ/OMatic/authenticate.pm:122
 "If you have already logged in earlier today, it may be that the token I use to identify you has expired. Please log in again."
 => "もしも既に本日ログインしていたならば、認証用トークンの有効期限切れである。再度ログインが必要。",

#: lib/FAQ/OMatic/authenticate.pm:136
 "Please offer one of the following forms of identification:"
 => "認識のために、以下のフォームのどれかを提出:",

#: lib/FAQ/OMatic/authenticate.pm:139
 "No authentication, but my email address is:"
 => "認証がないが、メールアドレスは:",

#: lib/FAQ/OMatic/authenticate.pm:140
 "Email:"
 => "メールアドレス:",

#: lib/FAQ/OMatic/authenticate.pm:147
 "Authenticated login:"
 => "認証ログイン:",

#: lib/FAQ/OMatic/authenticate.pm:149 lib/FAQ/OMatic/changePass.pm:71
 "Password:"
 => "パスワード:",

#: lib/FAQ/OMatic/changePass.pm:48
 "Please enter your username, and select a password."
 => "あなたの名前を入力し、パスワードを選択",

#: lib/FAQ/OMatic/changePass.pm:49
 "I will send a secret number to the email address you enter to verify that it is valid."
 => "認証を検査するために入力する暗証番号をメールアドレスに送った。",

#: lib/FAQ/OMatic/changePass.pm:50
 "If you prefer not to give your email address to this web form, please contact"
 => "もしも、このWebフォームでメールアドレスを提供しなかったら右記に連絡を:",

#: lib/FAQ/OMatic/changePass.pm:52
 "Please <b>do not</b> use a password you use anywhere else, as it will not be transferred or stored securely!"
 => "安全に保管も転送もされていないので、他の場所ではパスワードを<b>使ってはいけない</b>。",

#: lib/FAQ/OMatic/changePass.pm:73
 "Set Password"
 => "パスワード設定",

#: lib/FAQ/OMatic/editBag.pm:75
 "Replace bag"
 => "bagの置換",

#: lib/FAQ/OMatic/editBag.pm:81
 "Upload new bag to show in the %0 part in <b>%1</b>."
 => "<b>%1</>中のパート %0 中に表示するために新しいbagをアップロード",

#: lib/FAQ/OMatic/editBag.pm:96
 "Bag name:"
 => "Bag名:",

#: lib/FAQ/OMatic/editBag.pm:98
 "The bag name is used as a filename, so it is restricted to only contain letters, numbers, underscores (_), hyphens (-), and periods (.). It should also carry a meaningful extension (such as .gif) so that web browsers will know what to do with the data."
 => "バッグ名はファイル名として使用されるため、名前は英数字と下線(_)、ハイホン(-)とピリオド(.)に制限される。また、意味のある拡張子(例えば .gif)は伝達されるため、Webブラウザはデータに対して何をしたらいいかが分かる。",

#: lib/FAQ/OMatic/editBag.pm:99
 "Hint: Leave blank and Bag Data filename will be used."
 => "ヒント: 空白とBagデータファイル名を残すことは使うことが出来る",

#: lib/FAQ/OMatic/editBag.pm:102
 "Bag data:"
 => "Bagデータ:",

#: lib/FAQ/OMatic/editBag.pm:106
 "Inline (Images only):"
 => "インライン(イメージのみ)",

#: lib/FAQ/OMatic/editBag.pm:110
 "(Leave blank to keep original bag data and change only the associated information below.)"
 => "(オリジナルのbagデータを保持するために空白を取り除き関連する以下の情報だけ変更。)",

#: lib/FAQ/OMatic/editBag.pm:114
 "If this bag is an image, fill in its dimensions."
 => "もしもbagがイメージならばその次元を埋める",

#: lib/FAQ/OMatic/editBag.pm:115
 "Width:"
 => "幅:",

#: lib/FAQ/OMatic/editBag.pm:117
 "Height:"
 => "高さ:",

#: lib/FAQ/OMatic/editPart.pm:147
 "Enter the answer to <b>%0</b>"
 => "<b>%0</b> の回答を入力",

#: lib/FAQ/OMatic/editPart.pm:149
 "Enter a description for <b>%0</b>"
 => "<b>%0</b> の説明を入力",

#: lib/FAQ/OMatic/editPart.pm:151
 "Edit duplicated text for <b>%0</b>"
 => "<b>%0</b> の複製テキストを編集",

#: lib/FAQ/OMatic/editPart.pm:153
 "Enter new text for <b>%0</b>"
 => "<b>%0</b> の新しいテキストを入力",

#: lib/FAQ/OMatic/editPart.pm:158
 "Editing the %0 text part in <b>%1</b>."
 => "<b>%1</b> 中の %0 テキストパートを編集。",

#: lib/FAQ/OMatic/editPart.pm:172
 "If you later need to edit or delete this text, use the [Appearance] page to turn on the expert editing commands."
 => "もしも、このテキストを後で編集又は削除する必要がある場合、[見た目] ページで上級編集コマンドを有効にする必要がある。",

#: lib/FAQ/OMatic/install.pm:94
 "Faq-O-Matic Installer"
 => "Faq-O-Matic インストーラ",

#: lib/FAQ/OMatic/install.pm:122
#, c-format
 "%0 failed: "
 => "%0 が失敗した: ",

#: lib/FAQ/OMatic/install.pm:128
 "Unknown step: \"%0\"."
 => "不明のステップ: \"%0\".",

#: lib/FAQ/OMatic/install.pm:139
 "Updating config to reflect new meta location <b>%0</b>."
 => "新しいメタデータの位置 <b>%0</b> を反映させるために構成を更新",

#: lib/FAQ/OMatic/install.pm:157
 "(Can't find <b>config</b> in '%0' -- assuming this is a new installation.)"
 => "('%0' 中に <b>config</b> が見付からない -- 新しいインストールと仮定。)",

#: lib/FAQ/OMatic/install.pm:181
#, c-format
 "Click here</a> to create %0."
 => "%0 を作成するためにここをクリック</a>。",

#: lib/FAQ/OMatic/install.pm:183
 "If you want to change the CGI stub to point to another directory, edit the script and then"
 => "もしも、CGIスタブを別ディレクトリを示すように変更したいなら、スクリプトを編集し、",

#: lib/FAQ/OMatic/install.pm:186
 "click here to use the new location"
 => "新しいローケーションを使うためにここをクリック",

#: lib/FAQ/OMatic/install.pm:188
 "FAQ-O-Matic stores files in two main directories.<p>The <b>meta/</b> directory path is encoded in your CGI stub (%0). It contains:"
 => "FAQ-O-Matic はファイルを2つのディレクトリに格納する。<p><b>meta/</b>ディレクトリパスはCGIスタブ($0)中にエンコードされ、以下を含む:",

#: lib/FAQ/OMatic/install.pm:189
 "<ul><li>the <b>config</b> file that tells FAQ-O-Matic where everything else lives. That's why the CGI stub needs to know where meta/ is, so it can figure out the rest of its configuration. <li>the <b>idfile</b> file that lists user identities. Therefore, meta/ should not be accessible via the web server. <li>the <b>RCS/</b> subdirectory that tracks revisions to FAQ items. <li>various hint files that are used as FAQ-O-Matic runs. These can be regenerated automatically.</ul>"
 => "<ul><li><b>config</b>ファイルは稼働状況以外の、どこにFAQ-O-Maticの全てがあるかを記述する。それはなぜCGIスタブがどこに meta/ があるかを知る必要があると言う事であり、その構成の残りを指し示す。<li><b>idfile</b> はユーザ識別情報を保持する。そのため、meta/ はWeb サーバ経由でアクセスできてはいけない。<li><b>RCS/</b>サブディレクトリはFAQの各アイテムを追跡する。<li>種々のヒントファイルはFAQ-O-Matic実行時に使われる。それらは自動的に再生成される。</ul>",

#: lib/FAQ/OMatic/install.pm:190
 "<p>The <b>serve/</b> directory contains three subdirectories <b>item/</b>, <b>cache/</b>, and <b>bags/</b>. These directories are created and populated by the FAQ-O-Matic CGI, but should be directly accessible via the web server (without invoking the CGI)."
 => "<p><b>serve/</b>ディレクトリは3つのサブディレクトリ: <b>item/</b>, <b>cache/</b>と<b>bags/</b>を含む。それらのディレクトリは、FAQ-O-Matic-CGI によって作成され、一般化されるが、webサーバから(CGI起動なして)直接アクセス可能でなければならない。).",

#: lib/FAQ/OMatic/install.pm:191
 "<ul><li>serve/item/ contains only FAQ-O-Matic formatted source files, which encode both user-entered text and the hierarchical structure of the answers and categories in the FAQ. These files are only accessed through the web server (rather than the CGI) when another FAQ-O-Matic is mirroring this one. <li>serve/cache/ contains a cache of automatically-generated HTML versions of FAQ answers and categories. When possible, the CGI directs users to the cache to reduce load on the server. (CGI hits are far more expensive than regular file loads.) <li>serve/bags/ contains image files and other ``bags of bits.'' Bit-bags can be linked to or inlined into FAQ items (in the case of images). </ul>"
 => "<ul><li>serve/item/ は FAQ-O-Matic形式のソースファイルのみ保持し、それは、ユーザが入力したテキストとFAQ中の階層構造の回答とカテゴリをエンコードする。それらのファイルは、他のFAQ-O-Maticがそれをミラーする時は、webサーバを経由してのみ(というよりはCGI経由)アクセスできる。<li>serve/cache/ ディレクトリは自動的に生成された、HTMLバージョンのFAQの回答とカテゴリのキャッシュを保持する。もしも可能ならば、CGIはサーバ負荷の軽減のために、キャッシュを指し示す。(CGIのヒットは通常のファイルのロードよりははるかにコストがかかる。)<li>serve/bags/ はイメージファイルとその他の情報を含む。その他の情報のbagはFAQアイテム中にリンクできる(イメージの場合)。</ul>",

#: lib/FAQ/OMatic/install.pm:203 lib/FAQ/OMatic/install.pm:218
#: lib/FAQ/OMatic/install.pm:277 lib/FAQ/OMatic/install.pm:631
 "I couldn't create <b>%0</b>: %1"
 => "<b>%0</b>を作成できない: %1",

#: lib/FAQ/OMatic/install.pm:207 lib/FAQ/OMatic/install.pm:222
#: lib/FAQ/OMatic/install.pm:634
 "Created <b>%0</b>."
 => "<b>%0</b> を作成した。",

#: lib/FAQ/OMatic/install.pm:210 lib/FAQ/OMatic/install.pm:225
#: lib/FAQ/OMatic/install.pm:637
 "I don't have write permission to <b>%0</b>."
 => "<b>%0</b>に対する書き込み許可を持っていない。",

#: lib/FAQ/OMatic/install.pm:269
 "Created new config file."
 => "新しい構成ファイルを作成した。",

#: lib/FAQ/OMatic/install.pm:283
 "The idfile exists."
 => "idfile が存在している。",

#: lib/FAQ/OMatic/install.pm:332
 "Configuration Main Menu (install module)"
 => "構成メインメニュー(モジュールインストール)",

#: lib/FAQ/OMatic/install.pm:333
 "Perform these tasks in order to prepare your FAQ-O-Matic version %0:"
 => "あなたの FAQ-O-Matic バージョン %0を準備するためにこれらの処理を実行:",

#: lib/FAQ/OMatic/install.pm:338
 "Define configuration parameters"
 => "構成パラメータの定義",

#: lib/FAQ/OMatic/install.pm:343 lib/FAQ/OMatic/install.pm:348
 "Set your password and turn on installer security"
 => "パスワード設定し、インストーラのセキュリティを有効にする",

#: lib/FAQ/OMatic/install.pm:349
 "(Need to configure \$mailCommand and \$adminAuth)"
 => "(\$mailCommand と \$adminAuth の構成が必要)",

#: lib/FAQ/OMatic/install.pm:355
 "(Installer security is on)"
 => "(インストーラのセキュリティが有効)",

#: lib/FAQ/OMatic/install.pm:360
 "Create item, cache, and bags directories in serve dir"
 => "サーバ中のアイテム、キャッシュとbagディレクトリの作成",

#: lib/FAQ/OMatic/install.pm:368
 "Copy old items</a> from <tt>%0</tt> to <tt>%1</tt>."
 => "古いアイテム</a> を <tt>%0</tt> から <tt>%1</tt> に複写",

#: lib/FAQ/OMatic/install.pm:375
 "Install any new items that come with the system"
 => "システム由来の新しいアイテムのインストール",

#: lib/FAQ/OMatic/install.pm:380
 "Create system default items"
 => "システム既定値のアイテムの作成",

#: lib/FAQ/OMatic/install.pm:388
 "Rebuild the cache and dependency files"
 => "キャッシュと依存するファイルの再作成",

#: lib/FAQ/OMatic/install.pm:395
 "Install system images and icons"
 => "システム用のイメージとアイコンのインストール",

#: lib/FAQ/OMatic/install.pm:403
 "Update mirror from master now. (this can be slow!)"
 => "ミラーのマスタからの更新(遅い場合あり!)",

#: lib/FAQ/OMatic/install.pm:409
 "Set up the maintenance cron job"
 => "メンテナンス用cronジョブの設定",

#: lib/FAQ/OMatic/install.pm:415 lib/FAQ/OMatic/install.pm:420
 "Run maintenance script manually now"
 => "メンテナンススクリプトの手動実行",

#: lib/FAQ/OMatic/install.pm:422
 "(Need to set up the maintenance cron job first)"
 => "(最初にメンテナンスcronジョブの設定が必要)",

#: lib/FAQ/OMatic/install.pm:430
 "Maintenance last run at:"
 => "最後に実行されたもののメンテナンス:",

#: lib/FAQ/OMatic/install.pm:435
#, c-format
 "Mark the config file as upgraded to Version %0"
 => "構成ファイルをバージョン %0 にアップグレードするようにマーク",

#: lib/FAQ/OMatic/install.pm:441
 "Select custom colors for your Faq-O-Matic</a> (optional)"
 => "Faq-O-Matic用のカスタムカラーの選択</a> (任意)",

#: lib/FAQ/OMatic/install.pm:445
 "Define groups</a> (optional)"
 => "グループの定義</a> (任意)",

#: lib/FAQ/OMatic/install.pm:451
 "Upgrade to CGI.pm version 2.49 or newer."
 => "CGI.pm をバージョン 2.49 以降に更新せよ。",

#: lib/FAQ/OMatic/install.pm:454
 "(optional; older versions have bugs that affect bags)"
 => "(任意; 古いバージョンはbagに影響するバグを持つ)",

#: lib/FAQ/OMatic/install.pm:457
#, c-format
 "You are using version %0 now."
 => "現在バージョン %0 を使用している。",

#: lib/FAQ/OMatic/install.pm:462
 "Bookmark this link to be able to return to this menu."
 => "このメニューに戻れるように、リンクをブックマークに保存しなさい。",

#: lib/FAQ/OMatic/install.pm:473
 "(need to turn on installer security)"
 => "(インストーラのセキュリティを有効にする必要がある)",

#: lib/FAQ/OMatic/install.pm:476
 "Other available tasks:"
 => "他の有効なタスク:",

#: lib/FAQ/OMatic/install.pm:480
 "See access statistics"
 => "アクセス統計を見る",

#: lib/FAQ/OMatic/install.pm:485
 "Examine all bags"
 => "すべてのbagを検査",

#: lib/FAQ/OMatic/install.pm:491
 "Check for unreferenced bags (not linked by any FAQ item)"
 => "未参照のbag(FAQアイテムにリンクされていない)をチェック",

#: lib/FAQ/OMatic/install.pm:497
 "Empty old trash now"
 => "古いゴミ箱を今削除",

#: lib/FAQ/OMatic/install.pm:503
 "fsck (check and repair tree structure) now"
 => "fsck(木構造の検査と修復)",

#: lib/FAQ/OMatic/install.pm:509
 "rebuild search database now"
 => "検索データベースを今再構成",

#: lib/FAQ/OMatic/install.pm:517
 "Rebuild the cache and dependency files now"
 => "キャッシュと依存するファイルの再作成",

#: lib/FAQ/OMatic/install.pm:522
#, c-format
 "The Faq-O-Matic modules are version %0."
 => "Faq-O-Maticのモジュールのバージョンは %0。",

#: lib/FAQ/OMatic/install.pm:641
 "I wasn't able to change the permissions on <b>%0</b> to 755 (readable/searchable by all)."
 => "<b>%0</b> のパーミッションを 755 にできない(全てのユーザに 読み/検索を許可)。",

#: lib/FAQ/OMatic/install.pm:656 lib/FAQ/OMatic/install.pm:657
 "updated config file:"
 => "構成ファイルを更新:",

#: lib/FAQ/OMatic/install.pm:664
 "Redefine configuration parameters to ensure that <b>%0</b> is valid."
 => "<b>%0</b> の有効化を確実にするために構成ファイルパラメータを再定義。",

#: lib/FAQ/OMatic/install.pm:676
 "Jon made a mistake here; key=%0, property=%1."
 => "Jonはここでミスをした; key=%0, property=%1.",

#: lib/FAQ/OMatic/install.pm:705
 "<b>Mandatory:</b> System information"
 => "<b>必須:</b> システム情報",

#: lib/FAQ/OMatic/install.pm:708
 "Identity of local FAQ-O-Matic administrator (an email address)"
 => "ローカルの FAQ-O-Matic管理者の識別(メールアドレス)",

#: lib/FAQ/OMatic/install.pm:710
 "A command FAQ-O-Matic can use to send mail. It must either be sendmail, or it must understand the -s (Subject) switch."
 => "FAQ-O-Maticがメール送信に使うコマンド。それはsendmailか -s(題名)スイッチを認識しなければならない。",

#: lib/FAQ/OMatic/install.pm:712
 "The command FAQ-O-Matic can use to install a cron job."
 => "cronジョブをインストールするのに使うコマンド。",

#: lib/FAQ/OMatic/install.pm:716
 "Path to the <b>ci</b> command from the RCS package."
 => "RCSパッケージの <b>ci</b> コマンドへのパス。",

#: lib/FAQ/OMatic/install.pm:719
 "Path to the <b>co</b> command from the RCS package."
 => "RCSパッケージの <b>co</b> コマンドへのパス。",

#: lib/FAQ/OMatic/install.pm:722
 "<b>Mandatory:</b> Server directory configuration"
 => "<b>必須:</b> サーバディレクトリ構成",

#: lib/FAQ/OMatic/install.pm:724
 "Protocol, host, and port parts of the URL to your site. This will be used to construct link URLs. Omit the trailing '/'; for example: <tt>http://www.dartmouth.edu</tt>"
 => "作成サイトのURLのプロトコル、ホストとポート番号部分。これはURLのリンクの構築に使われる。最後の '/'を省略しなさい。例:<tt>http://www.dartmouth.edu</tt>",

#: lib/FAQ/OMatic/install.pm:727
 "The path part of the URL used to access this CGI script, beginning with '/' and omitting any parameters after the '?'. For example: <tt>/cgi-bin/cgiwrap/jonh/faq.pl</tt>"
 => "このCGIスクリプトにアクセスするためのURLのパスの部分で、'/'で始まり、'?'以降の任意のパラメータを省略。例:<tt>/cgi-bin/cgiwrap/jonh/faq.pl</tt>",

#: lib/FAQ/OMatic/install.pm:730
 "Filesystem directory where FAQ-O-Matic will keep item files, image and other bit-bag files, and a cache of generated HTML files. This directory must be accessible directly via the http server. It might be something like /home/faqomatic/public_html/fom-serve/"
 => "FAQ-O-Maticがアイテムファイル、イメージとその他のもののbagファイルを保持し、作成したHTMLファイルをキャッシュするディレクトリ。このディレクトリはhttpサーバ経由でアクセスできねばならない。たとえば、/home/faqomatic/public_html/fom-serve/である。",

#: lib/FAQ/OMatic/install.pm:732
 "The path prefix of the URL needed to access files in <b>\$serveDir</b>. It should be relative to the root of the server (omit http://hostname:port, but include a leading '/'). It should also end with a '/'."
 => "<b>\$serveDir</b>中のファイルにアクセスするのに必要なURLのプレフィックスのパス。これはサーバのrootからの相対パスでなければならない(http://hostname:portは省略できるが、先行する'/' は含まなければならない。)。また、'/'で終る必要がある。",

#: lib/FAQ/OMatic/install.pm:735
 "<i>Optional:</i> Miscellaneous configurations"
 => "<i>任意:</i> その他の構成設定",

#: lib/FAQ/OMatic/install.pm:740
 "Select the display language."
 => "表示言語を選択",

#: lib/FAQ/OMatic/install.pm:741
 "'en'"
 => "'ja_JP.EUC'",

#: lib/FAQ/OMatic/install.pm:745
 "Show dates in 24-hour time or am/pm format."
 => "時間を24時間制/午前午後形式で表示。",

#: lib/FAQ/OMatic/install.pm:749
 "If this parameter is set, this FAQ will become a mirror of the one at the given URL. The URL should be the base name of the CGI script of the master FAQ-O-Matic."
 => "もしもこのパラメータが設定されると、このFAQは与えられたURLのミラーとなる。URLはマスターFAQ-O-MaticのCGIスクリプトのベースネームでなければならない。",

#: lib/FAQ/OMatic/install.pm:751
 "An HTML fragment inserted at the top of each page. You might use this to place a corporate logo."
 => "それぞれのページの先頭に挿入されるHTMLフラグメント。会社のロゴを配置するのに使える。",

#: lib/FAQ/OMatic/install.pm:753 lib/FAQ/OMatic/install.pm:766
 "If this field begins with <tt>file=</tt>, the text will come from the named file in the meta directory; otherwise, this field is included verbatim."
 => "もしもフィールドが <tt>file=</tt> で始まるならば、テキストはメタディレクトリ中の名前付けられたファイルから来る。それ例外は、このフィールドはverbatimを含む。",

#: lib/FAQ/OMatic/install.pm:761
 "The <tt>width=</tt> tag in a table. If your <b>\$pageHeader</b> has <tt>align=left</tt>, you will want to make this empty."
 => "テーブル中の<tt>width=</tt> タグ。もしも <b>\$pageHeader</b> が <tt>align=left</tt>ならば、これを空白にしてもよい。",

#: lib/FAQ/OMatic/install.pm:764
 "An HTML fragment appended to the bottom of each page. You might use this to identify the webmaster for this site."
 => "各ページの末尾に追加されるHTMLフラグメント。このサイトのWeb管理者を表示するのに使える。",

#: lib/FAQ/OMatic/install.pm:769
 "Where FAQ-O-Matic should send email when it wants to alert the administrator (usually same as \$adminAuth)"
 => "FAQ-O-Maticが、管理者に警告を送ろうとする時に、送る先のメールアドレス(通常は\$adminAuthと同一)",

#: lib/FAQ/OMatic/install.pm:771
 "If true, FAQ-O-Matic will mail the log file to the administrator whenever it is truncated."
 => "もしも真ならば、FAQ-O-Maticはログファイルが縮められた時には必ずメールする。",

#: lib/FAQ/OMatic/install.pm:774
 "User to use for RCS ci command (default is process UID)"
 => "RCS ci コマンドを使うユーザ(既定値ではプロセスのUID)",

#: lib/FAQ/OMatic/install.pm:778
 "Links from cache to CGI are relative to the server root, rather than absolute URLs including hostname:"
 => "ホスト名を含む絶対URLというよりはサーバルートからCGIキャッシュへの相対リンク:",

#: lib/FAQ/OMatic/install.pm:782
 "mailto: links can be rewritten such as jonhATdartmouthDOTedu (cheesy), jonh (nameonly), or e-mail addresses suppressed entirely (hide)."
 => "mailto: リンクは jonhATdartmouthDOTedu (擬似的)、jonh(名前のみ)又はメールアドレスが完全に抑圧される(隠蔽)ように書き換えることが出来る。",

#: lib/FAQ/OMatic/install.pm:786
 "Number of seconds that authentication cookies remain valid. These cookies are stored in URLs, and so can be retrieved from a browser history file. Hence they should usually time-out fairly quickly."
 => "認証クッキーが有効な秒数。このクッキーはURLに保存され、ブラウザヒストリファイルから検索できる。そのため、あまり早くタイムアウトにならないように設定。",

#: lib/FAQ/OMatic/install.pm:790
 "Number of days that trash sits in the trash category before maintenance cleans it up. '0' lets it stay forever."
 => "保守時に削除してしまう前に、ごみがゴミ箱(trash)カテゴリ中に居座っている日数。'0'を指定すると永遠に保持される。",

#: lib/FAQ/OMatic/install.pm:793
 "<i>Optional:</i> These options set the default [Appearance] modes."
 => "<i>任意:</i> これらのオプションが[Appearance]モードの既定値に設定。",

#: lib/FAQ/OMatic/install.pm:798
 "Page rendering scheme. Do not choose 'text' as the default."
 => "ページレンダリングスキーム。'text'を既定値として選んではならない。",

#: lib/FAQ/OMatic/install.pm:826
 "<i>Optional:</i> These options fine-tune the appearance of editing features."
 => "<i>任意:</i> これらのオプションは編集機能向けのの見栄えに良く調整されている。",

#: lib/FAQ/OMatic/install.pm:829
 "The old [Show Edit Commands] button appears in the navigation bar."
 => "古い[編集コマンドを表示]ボタンはナビゲータバーにある。",

#: lib/FAQ/OMatic/install.pm:833
 "Navigation links appear at top of page as well as at the bottom."
 => "ナビゲーションリンクは末尾と同じようにページの先頭にある。",

#: lib/FAQ/OMatic/install.pm:837
 "Hide [Append to This Answer] and [Add New Answer in ...] buttons."
 => "[この回答を追加]と[新しい回答を追加...]ボタンを隠す。",

#: lib/FAQ/OMatic/install.pm:842
 "Editing commands appear with neat-o icons rather than [In Brackets]."
 => "[ブラケット中]というよりは編集コマンドは neat-oアイコンと一緒にある。",

#: lib/FAQ/OMatic/install.pm:845
 "<i>Optional:</i> Other configurations that you should probably ignore if present."
 => "<i>任意:</i> もしも存在するならば、その他の構成は無視すべきである。",

#: lib/FAQ/OMatic/install.pm:849
 "Draw Item titles John Nolan's way."
 => "アイテムタイトルをJohn Nolan流で描画。",

#: lib/FAQ/OMatic/install.pm:853
 "Hide sibling (Previous, Next) links"
 => "(前、次)兄弟リンクを隠す",

#: lib/FAQ/OMatic/install.pm:857
 "Use DBM-based search databases. Faster on machines with non-broken DBM."
 => "DBMベースの検索データベースを使う。壊れていないDBMのマシンのものを使うより早い。",

#: lib/FAQ/OMatic/install.pm:860
 "Links from search results page point into cache (do not highlight search terms)"
 => "検索の結果をキャッシュ中のページを指すようにする(検索語をハイライト)しない",

#: lib/FAQ/OMatic/install.pm:865
 "Arguments to make ci quietly log changes and not mash RCS tags (use default with GNU RCS)"
 => "表示無しにログの変更をciコマンドにさせ、RCSタグをつぶさせない引数(GNU RCSで既定値として使う",

#: lib/FAQ/OMatic/install.pm:868
 "Arguments to make co not mash RCS tags (use default with GNU RCS)"
 => "coにRCSタグをつぶさせない引数(GNU RCSで既定値として使う)",

#: lib/FAQ/OMatic/install.pm:974
 "This is a command, so only letters, hyphens, and slashes are allowed."
 => "これはコマンドなので、英数字、ハイホンとスラッシュのみが有効。",

#: lib/FAQ/OMatic/install.pm:1033
 "If this is your first time installing a FAQ-O-Matic, I recommend only filling in the sections marked <b>Mandatory</b>."
 => "もしも最初のFAQ-O-Maticのインストールならば、<b>必須</b>とマークされたセクションのみを埋める事を推奨。",

#: lib/FAQ/OMatic/install.pm:1037
 "Define"
 => "定義",

#: lib/FAQ/OMatic/install.pm:1080
 "You should <a href=\"%0\">go back</a> and fix these configurations."
 => "<a href=\"%0\">戻る</a> に戻り、それらの構成を修正しなければならない。",

#: lib/FAQ/OMatic/install.pm:1083
 "Rewrote configuration file."
 => "構成ファイルを再書き込み。",

#: lib/FAQ/OMatic/install.pm:1097
 "%0 (%1) has an internal apostrophe, which will certainly make Perl choke on the config file."
 => "%0 (%1) は内部にアポストロフィがあり、それは構成ファイル上で確実にPerlを止める。",

#: lib/FAQ/OMatic/install.pm:1101 lib/FAQ/OMatic/install.pm:1107
 "%0 (%1) doesn't look like a fully-qualified email address."
 => "%0 (%1) は完全に記述されている電子メールアドレスではない。",

#: lib/FAQ/OMatic/install.pm:1113 lib/FAQ/OMatic/install.pm:1118
 "%0 (%1) isn't executable."
 => "%0 (%1) は実行できない。",

#: lib/FAQ/OMatic/install.pm:1135
 "%0 has funny characters."
 => "%0 には不正な文字がある。",

#: lib/FAQ/OMatic/install.pm:1170
 "To name your FAQ-O-Matic, use the [Appearance] page to show the expert editing commands, then click [Edit Category Title and Options]."
 => "FAQ-O-Maticに名前を付けるために、[見た目]ページで上級編集コマンドを見えるように使い、[カテゴリタイトルとオプションの編集]をクリック",

#: lib/FAQ/OMatic/install.pm:1180 lib/FAQ/OMatic/install.pm:1192
#: lib/FAQ/OMatic/install.pm:1204
 "Created category \"%0\"."
 => "\"%0\"カテゴリを作成した。",

#: lib/FAQ/OMatic/install.pm:1182 lib/FAQ/OMatic/install.pm:1194
#: lib/FAQ/OMatic/install.pm:1206
 "<b>%0</b> already contains a file '%1'."
 => "<b>%0</b> はすでにファイル '%1' を含んでいる。",

#: lib/FAQ/OMatic/install.pm:1244
 "Copied %0 items from <tt>%1</tt> to <tt>%2</tt>."
 => "%0 アイテムを、<tt>%1</tt>から<tt>%2</tt>へコピーした。",

#: lib/FAQ/OMatic/install.pm:1301
 "Attempting to install cron job:"
 => "cronジョブのインストールを試みる:",

#: lib/FAQ/OMatic/install.pm:1349
 "I replaced this old crontab line, which appears to be an older one for this same FAQ:"
 => "この同じFAQの古い物に見えるような、古いcrontab行をリプレースした:",

#: lib/FAQ/OMatic/install.pm:1358
 "I thought I installed a new cron job, but it didn't appear to take."
 => "新しいcronジョブをインストールしたが、そのように見えないと思う。",

#: lib/FAQ/OMatic/install.pm:1360
 "You better add %0 to some crontab yourself with <b><tt>crontab -e</tt></b>"
 => "%0 をいくつかのcrontabに、<b><tt>crontab -e</tt></b> を使って御自身で追加した方が良い。",

#: lib/FAQ/OMatic/install.pm:1366
 "Cron job installed. The maintenance script should run hourly."
 => "Cronジョブをインストールした。管理スクリプトを毎時動かすべきである。",

#: lib/FAQ/OMatic/install.pm:1422
 "Use the <u>%0</u> links to change the color of a feature."
 => "<u>%0</u> リンクを、機能の色を変更するために使う。",

#: lib/FAQ/OMatic/install.pm:1436
 "An Item Title"
 => "アイテムの題名",

#: lib/FAQ/OMatic/install.pm:1444
 "A regular part is how most of your content will appear. The text colors should be most pleasantly readable on this background."
 => "通常のパートはどのようにほとんどのコンテンツを見せるかである。テキストの色はこの背景上でほとんど快適に読める。",

#: lib/FAQ/OMatic/install.pm:1446 lib/FAQ/OMatic/install.pm:1458
#: lib/FAQ/OMatic/install.pm:1485
 "A new link"
 => "新しいリンク",

#: lib/FAQ/OMatic/install.pm:1447 lib/FAQ/OMatic/install.pm:1459
#: lib/FAQ/OMatic/install.pm:1489
 "A visited link"
 => "訪れたリンク",

#: lib/FAQ/OMatic/install.pm:1449 lib/FAQ/OMatic/install.pm:1461
#: lib/FAQ/OMatic/install.pm:1494
 "A search hit"
 => "検索にヒット",

#: lib/FAQ/OMatic/install.pm:1457
 "A directory part should stand out"
 => "ディレクトリ部分はstand outすべき",

#: lib/FAQ/OMatic/install.pm:1481
 "Regular text"
 => "通常のテキスト",

#: lib/FAQ/OMatic/install.pm:1506
 "Select a color for %0:"
 => "%0 の色を選択:",

#: lib/FAQ/OMatic/install.pm:1517
 "Or enter an HTML color specification manually:"
 => "又は、HTML色指定を手動で入力:",

#: lib/FAQ/OMatic/install.pm:1520
 "Select"
 => "選択",

#: lib/FAQ/OMatic/install.pm:1529
 "Unrecognized config parameter"
 => "不明な構成パラメータ",

#: lib/FAQ/OMatic/install.pm:1577
#, c-format
 "Proceed to step '%0'"
 => "ステップ '%0' の実行",

#: lib/FAQ/OMatic/install.pm:1708
 "You must enter the correct temporary password to install this FAQ-O-Matic. If you don't know it, remake the CGI stub to have a new one assigned."
 => "FAO-O-Maticをインストールするために正しい一時パスワードを入力する必要がある。もしもその方法を知らないならば、CGIスタブを、新しいパスワードを割り当てるために再作成せよ。",

#: lib/FAQ/OMatic/install.pm:1711
 "Temporary password: "
 => "一時パスワード: ",

#: lib/FAQ/OMatic/moveItem.pm:114
 "Make <b>%0</b> belong to which other item?"
 => "<b>%0</b> をどちらのアイテムに属させるか?",

#: lib/FAQ/OMatic/moveItem.pm:118
 "No item that already has sub-items can become the parent of"
 => "右記の親になれる、既にサブアイテムを持つアイテムがない",

#: lib/FAQ/OMatic/moveItem.pm:120
 "No item can become the parent of"
 => "右記の親のアイテムになれる物が無い",

#: lib/FAQ/OMatic/moveItem.pm:124
 "Some destinations are not available (not clickable) because you do not have permission to edit them as currently authorized."
 => "いくつかのディストネーションは無効で(クリックできない)あり、それは、現在の認証状態ではそれらの編集権限が無いためである。",

#: lib/FAQ/OMatic/moveItem.pm:127
 "Click here</a> to provide better authentication."
 => "より良い認証を提供するためここをクリック</a>。",

#: lib/FAQ/OMatic/moveItem.pm:133
 "Hide answers, show only categories"
 => "回答を隠し、カテゴリのみ表示",

#: lib/FAQ/OMatic/moveItem.pm:136
 "Show both categories and answers"
 => "カテゴリと回答両方を表示",

#: lib/FAQ/OMatic/recent.pm:62
#, c-format
 "No items were modified in the last %0."
 => "最後の %0 中で何のアイテムも変更されなかった。",

#: lib/FAQ/OMatic/recent.pm:65
 "Items modified in the last %0:"
 => "最後の %0 中で アイテムが変更された。",

#: lib/FAQ/OMatic/search.pm:72
 "No items matched all of these words"
 => "それらの単語のすべてでアイテムに一致したものはなかった",

#: lib/FAQ/OMatic/search.pm:76
#, c-format
 "No items matched at least %0 of these words"
 => "少なくともそれらの %0 の語でアイテムに一致したものはなかった",

#: lib/FAQ/OMatic/search.pm:85
 "Search results for all of these words"
 => "全ての語のための検索結果",

#: lib/FAQ/OMatic/search.pm:89
#, c-format
 "Search results for at least %0 of these words"
 => "少なくともそれらの語の %0 のための検索結果",

#: lib/FAQ/OMatic/search.pm:106
 "Results may be incomplete, because the search index has not been refreshed since the most recent change to the database."
 => "検索索引がデータベースの最新の変更以来更新されていないため、結果は不完全な可能性がある。",

#: lib/FAQ/OMatic/searchForm.pm:53
 "search for keywords"
 => "検索のためのキーワード",

#: lib/FAQ/OMatic/searchForm.pm:58
 "Search for"
 => "検索対象:",

#: lib/FAQ/OMatic/searchForm.pm:59
 "matching"
 => "一致",

#: lib/FAQ/OMatic/searchForm.pm:61
 "all"
 => "すべて",

#: lib/FAQ/OMatic/searchForm.pm:62
 "any"
 => "任意",

#: lib/FAQ/OMatic/searchForm.pm:63
 "two"
 => "2つ",

#: lib/FAQ/OMatic/searchForm.pm:64
 "three"
 => "3つ",

#: lib/FAQ/OMatic/searchForm.pm:65
 "four"
 => "4つ",

#: lib/FAQ/OMatic/searchForm.pm:66
 "five"
 => "5つ",

#: lib/FAQ/OMatic/searchForm.pm:68
 "words"
 => "語",

#: lib/FAQ/OMatic/searchForm.pm:76
 "search for recent changes"
 => "最近の変更を検索",

#: lib/FAQ/OMatic/searchForm.pm:82
 "Show documents"
 => "ドキュメント表示",

#: lib/FAQ/OMatic/searchForm.pm:83
 "modified in the last"
 => "最後で変更",

#: lib/FAQ/OMatic/selectBag.pm:69
 "Replace which bag?"
 => "どのbagを置換?",

#: lib/FAQ/OMatic/stats.pm:69
 "Hits Per Day"
 => "一日あたりのヒット数",

#: lib/FAQ/OMatic/stats.pm:70
 "Cumulative Hits"
 => "累積ヒット数",

#: lib/FAQ/OMatic/stats.pm:74
 "New Hosts Per Day"
 => "一日あたりの新規ホスト数",

#: lib/FAQ/OMatic/stats.pm:75
 "Total Hosts"
 => "トータルホスト数",

#: lib/FAQ/OMatic/stats.pm:79
 "Hits Per Host"
 => "ホストあたりのヒット数",

#: lib/FAQ/OMatic/stats.pm:80
 "Cumulative Searches"
 => "累積検索数",

#: lib/FAQ/OMatic/stats.pm:83
 "Submissions Per Day"
 => "一日あたりの投稿数",

#: lib/FAQ/OMatic/stats.pm:84
 "Cumulative Submissions"
 => "累積投稿数",

#: lib/FAQ/OMatic/stats.pm:87
 "Please be patient ... the image files are generated dynamically, and can take from 20 to 50 seconds to create.\n"
 => "少々お待ちを.... イメージファイルは動的に作成されるため、作成に20から50秒かかる.\n",

#: lib/FAQ/OMatic/stats.pm:137
 "Change View Duration"
 => "表示期間",

#: lib/FAQ/OMatic/stats.pm:140
 "One Month"
 => "一ヶ月",

#: lib/FAQ/OMatic/stats.pm:142
 "Two Months"
 => "二ヶ月",

#: lib/FAQ/OMatic/stats.pm:144
 "Three Months"
 => "三ヶ月",

#: lib/FAQ/OMatic/stats.pm:146
 "History"
 => "履歴",

#: lib/FAQ/OMatic/submitBag.pm:74
 "Bag names may only contain letters, numbers, underscores (_), hyphens (-), and periods (.), and may not end in '.desc'. Yours was"
 => "bag名は英数字、下線(_)、ハイホン(-)とピリオド(.)のみが有効で'.desc'で終ってはいけない。→",

#: lib/FAQ/OMatic/submitItem.pm:61
 "Your browser or WWW cache has truncated your POST."
 => "ブラウザかWWWキャッシュがあなたのPOSTを切り詰めた。",

#: lib/FAQ/OMatic/submitItem.pm:72
 "Changed the item title, was \"%0\""
 => "項目タイトルが \"%0\" に変更された。",

#: lib/FAQ/OMatic/submitItem.pm:88 lib/FAQ/OMatic/submitItem.pm:98
 "Your part order list (%0) "
 => "あなたの部分オーダリスト (%0) ",

#: lib/FAQ/OMatic/submitItem.pm:89
 "doesn't have the same number of parts (%0) as the original item."
 => "オリジナルアイテムと同じ数のパート (%0) を持つ事が出来ない。",

#: lib/FAQ/OMatic/submitItem.pm:99
#, c-format
 "doesn't say what to do with part %0."
 => "パート %0 について何であるかを言う事が出来ない。",

#: lib/FAQ/OMatic/submitMove.pm:51
 "The moving file (%0) is broken or missing."
 => "移動したファイル(%0)は壊れているか存在しない。",

#: lib/FAQ/OMatic/submitMove.pm:57
 "The newParent file (%0) is broken or missing."
 => "新しい親ファイル(%0)は壊れているか存在しない。",

#: lib/FAQ/OMatic/submitMove.pm:66
 "The oldParent file (%0) is broken or missing."
 => "古い親ファイル(%0)は壊れているか存在しない。",

#: lib/FAQ/OMatic/submitMove.pm:74
 "The new parent (%0) is the same as the old parent."
 => "新しい親(%0)は古い親と同じである。",

#: lib/FAQ/OMatic/submitMove.pm:79
 "The new parent (%0) is the same as the item you want to move."
 => "新しい親(%0)は移動対象の物と同じである。",

#: lib/FAQ/OMatic/submitMove.pm:86
 "The new parent (%0) is a child of the item being moved (%1)."
 => "新しい親(%0)は移動して来た子(%1) である。",

#: lib/FAQ/OMatic/submitMove.pm:92
 "You can't move the top item."
 => "最上位のアイテムは移動できない。",

#: lib/FAQ/OMatic/submitMove.pm:130
#, c-format
 "moved a sub-item to %0"
 => "サブアイテムを %0 に移動した",

#: lib/FAQ/OMatic/submitMove.pm:133
#, c-format
 "moved a sub-item from %0"
 => "サブアイテムを %0 から移動した",

#: lib/FAQ/OMatic/submitPass.pm:49
 "An email address must look like 'name\@some.domain'."
 => "電子メールアドレスは 'name\@some.domain' の形でなければならない。",

#: lib/FAQ/OMatic/submitPass.pm:51
 "If yours (%0) does and I keep rejecting it, please mail the administrator of this FAQ at %1 and tell him or her what's happening."
 => "もしもあなたのFOMに(%0)があり、私がそれを排除しつづけたいなら、何が起きたかをこのFAQの管理者 %1 にメールして欲しい。",

#: lib/FAQ/OMatic/submitPass.pm:58
 "Your password may not contain spaces or carriage returns."
 => "あなたのパスワードには空白や改行を含んではならない。",

#: lib/FAQ/OMatic/submitPass.pm:97
 "Your Faq-O-Matic authentication secret"
 => "あなたの Faq-O-Matic 認証のための情報",

#: lib/FAQ/OMatic/submitPass.pm:98
 "To validate your Faq-O-Matic password, you may either enter this secret into the Validation form:"
 => "Faq-O-Matic用のパスワードを検証するため、検証用フォームに秘密のキーを入力してもよい。",

#: lib/FAQ/OMatic/submitPass.pm:99 lib/FAQ/OMatic/submitPass.pm:136
 "Secret:"
 => "認証情報:",

#: lib/FAQ/OMatic/submitPass.pm:100
 "Or access the following URL. Be careful when you copy and paste the URL that the line-break doesn't cut the URL short."
 => "または、以下のURLにアクセスする。URLのコピーと貼り付けを行なう際に、改行がURLをカットしないように気をつけなければならない。",

#: lib/FAQ/OMatic/submitPass.pm:101
 "Thank you for using Faq-O-Matic."
 => "Faq-O-Maticに移動",

#: lib/FAQ/OMatic/submitPass.pm:102
 "(Note: if you did not sign up to use the Faq-O-Matic, someone else has attempted to log in using your name. Do not access the URL above; it will validate the password that user has supplied. Instead, send mail to %0 and I will look into the matter.)"
 => "(注意: もしもFaq-O-Maticを使うためにサインアップしないならば、だれかがあなたの名前でログインしようと試みるだろう。上記のURLにアクセスしてはならない。それはユーザに割り当てられたパスワードを検証するだろう。その代わりに、メールを%0に送り、それを処理するだろう。",

#: lib/FAQ/OMatic/submitPass.pm:106
 "I couldn't mail the authentication secret to \"%0\" and I'm not sure why."
 => "認証のための情報を \"%0\" に送れなかったが理由が分からない。",

#: lib/FAQ/OMatic/submitPass.pm:116
 "The secret you entered is not correct."
 => "入力された認証情報が不正である。",

#: lib/FAQ/OMatic/submitPass.pm:118
 "Did you copy and paste the secret or the URL completely?"
 => "認証情報またはURLを正しくコピー＆ペーストしたか?",

#: lib/FAQ/OMatic/submitPass.pm:122
 "I sent email to you at \"%0\". It should arrive soon, containing a URL."
 => "メールを\"%0\" に送った。その中にURLが含まれている。まもなく到着するだろう。",

#: lib/FAQ/OMatic/submitPass.pm:126
 "Either open the URL directly, or paste the secret into the form below and click Validate."
 => "URLを直接開くか、認証情報を以下のフォームにペーストしてクリックして認証せよ。",

#: lib/FAQ/OMatic/submitPass.pm:128
 "Thank you for taking the time to sign up."
 => "認証作業が完了。",

#~ msgid "Your Faq-O-Matic would have a title "
#~ msgstr "インストーラを走らせた時にできる"

#~ msgid "installer."
#~ msgstr "タイトルを持つだろう。"

#~ msgid "deprecated; subsumed by RCSciArgs and RCScoArgs."
#~ msgstr "不賛成; RCSciArgsとRCScoArgsによって包含されている。"

#~ msgid "You must enter the correct temporary password to install "
#~ msgstr "インストールするために正しい一時パスワードをこのFAO-O-Matic用に"

#~ msgid "this FAQ-O-Matic. If you don't know it, remake the CGI stub "
#~ msgstr "入力しなければならない。もしも、それが不明ならば、CGIスタブを"

#~ msgid "to have a new one assigned."
#~ msgstr "新しく割り当てるために再作成しなさい。"

#~ msgid "Temporary password: <input type=password size=36 name=temppass>\n"
#~ msgstr "一時パスワード: <input type=password size=36 name=temppass>\n"


);  # end of %data hash

    my $msgid;

    foreach $msgid (keys(%data))
    {
        $tx->{$msgid} = $data{$msgid};
    }
    return 1;
}
