#--------------------------------------------------------------------
#   Language_hu.pm
#   Generated automatically from hu.po by po2pm
#--------------------------------------------------------------------

sub translations {
    my $tx = shift;

    my %data = (

# SOME DESCRIPTIVE TITLE.
# Copyright (C) YEAR Free Software Foundation, Inc.
# Endre ZELENA <ezelena@users.sourceforge.net>, 2003.
#
#, fuzzy
 ""
# fuzzy # => "Project-Id-Version: PACKAGE VERSION\nPOT-Creation-Date: 2003-03-18 15:02+0100\nPO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\nLast-Translator: Endre ZELENA <ezelena@users.sourceforge.net>\nLanguage-Team: LANGUAGE <LL@li.org>\nMIME-Version: 1.0\nContent-Type: text/plain; charset=iso8859-2\nContent-Transfer-Encoding: 8bit\n",
 => "",

#: lib/FAQ/OMatic.pm:96 lib/FAQ/OMatic/install.pm:1079
 "Warnings:"
 => "Figyelmeztetés:",

#: lib/FAQ/OMatic.pm:111
 "Your Faq-O-Matic would have a title if it had an item 1, which it will when you've run the installer."
 => "",

#: lib/FAQ/OMatic.pm:114 lib/FAQ/OMatic/install.pm:1164
 "Untitled Faq-O-Matic"
 => "Untitled Faq-O-Matic",

#: lib/FAQ/OMatic.pm:136 lib/FAQ/OMatic/authenticate.pm:151
 "Log In"
 => "Bejelentkezés",

#: lib/FAQ/OMatic.pm:137
 "Change Password"
 => "Jelszó módosítás",

#: lib/FAQ/OMatic.pm:138
#, c-format
 "Edit Title of %0 %1"
 => "Cím szerkesztése: %0 %1",

#: lib/FAQ/OMatic.pm:139
#, c-format
 "New %0"
 => "Új %0",

#: lib/FAQ/OMatic.pm:140
#, c-format
 "Edit Part in %0 %1"
 => "Elem szerkesztése: %0 %1",

#: lib/FAQ/OMatic.pm:141
#, c-format
 "Insert Part in %0 %1"
 => "Elem beilelsztése: %0 %1",

#: lib/FAQ/OMatic.pm:142
#, c-format
 "Move %0 %1"
 => "Mozgat: %0 %1",

#: lib/FAQ/OMatic.pm:143 lib/FAQ/OMatic/Appearance.pm:168
 "Search"
 => "Keresés",

#: lib/FAQ/OMatic.pm:144
 "Access Statistics"
 => "Statisztikák",

#: lib/FAQ/OMatic.pm:145 lib/FAQ/OMatic/submitPass.pm:138
 "Validate"
 => "Megerősít",

#: lib/FAQ/OMatic.pm:146
 "%0 Permissions for %1"
 => "%0 Permissions for %1",

#: lib/FAQ/OMatic.pm:147
#, c-format
 "Upload bag for %0 %1"
 => "Csomag feltöltése: %0 %1",

#: lib/FAQ/OMatic.pm:1663
 "http-charset"
 => "",

#: lib/FAQ/OMatic/Appearance.pm:177
 "Appearance"
 => "Megjelenés",

#: lib/FAQ/OMatic/Appearance.pm:191
 "Show Top Category Only"
 => "Csak a top kategória mutatása",

#: lib/FAQ/OMatic/Appearance.pm:198
 "Show This <em>Entire</em> Category"
 => "A <em>teljes</em> kategória megjelenítése",

#: lib/FAQ/OMatic/Appearance.pm:209
 "Show This Category As Text"
 => "A kategória mutatása szövegként",

#: lib/FAQ/OMatic/Appearance.pm:213
 "Show This Answer As Text"
 => "A válasz mutatása szövegként",

#: lib/FAQ/OMatic/Appearance.pm:218
 "Show This %0 As Text"
 => "A %0 mutatása szövegként",

#: lib/FAQ/OMatic/Appearance.pm:232
 "Show This <em>Entire</em> Category As Text"
 => "A <em>teljes</em> kategóriát mutatása szövegként",

#: lib/FAQ/OMatic/Appearance.pm:244
 "Hide Expert Edit Commands"
 => "Szerkesztő parancsok elrejtése",

#: lib/FAQ/OMatic/Appearance.pm:253
 "Show Expert Edit Commands"
 => "Szerkesztő parancsok mutatása",

#: lib/FAQ/OMatic/Appearance.pm:269 lib/FAQ/OMatic/Item.pm:2224
#: lib/FAQ/OMatic/stats.pm:133
 "Return to the FAQ"
 => "Vissza a kezdőoldalra",

#: lib/FAQ/OMatic/Appearance.pm:276
 "This is a"
 => " ",

#: lib/FAQ/OMatic/Auth.pm:495
 "the administrator of this Faq-O-Matic"
 => "Ennek a Faq-O-Matic-nak az adminisztrátora",

#: lib/FAQ/OMatic/Auth.pm:496
 "someone who has proven their identification"
 => "azonosított felhasználó",

#: lib/FAQ/OMatic/Auth.pm:497
 "someone who has offered identification"
 => "someone who has offered identification",

#: lib/FAQ/OMatic/Auth.pm:498
 "anybody"
 => "bárki",

#: lib/FAQ/OMatic/Auth.pm:511
 "the moderator of the item"
 => "a terület moderátora",

#: lib/FAQ/OMatic/Auth.pm:515
#, c-format
 "%0 group members"
 => "a(z) %0 csoport tagjai",

#: lib/FAQ/OMatic/Groups.pm:142
 "Select a group to edit:"
 => "Módosítani kívánt csoport:",

#: lib/FAQ/OMatic/Groups.pm:150
 "(Members of this group are allowed to access these group definition pages.)"
 => "(Ennek a csoportnak a tagjai elérhetik ezeket az oldalakat.)",

#: lib/FAQ/OMatic/Groups.pm:168
 "Add Group"
 => "Csoport létrehozása",

#: lib/FAQ/OMatic/Groups.pm:175
 "Up To List Of Groups"
 => "Vissza a csoportok listájához",

#: lib/FAQ/OMatic/Groups.pm:187
 "Remove Member"
 => "Eltávolítás a csoportból",

#: lib/FAQ/OMatic/Groups.pm:196
 "Add Member"
 => "Tag felvétele a csoportba",

#: lib/FAQ/OMatic/Groups.pm:206 lib/FAQ/OMatic/install.pm:467
#: lib/FAQ/OMatic/install.pm:471
 "Go to the Faq-O-Matic"
 => "Tovább a főoldalra",

#: lib/FAQ/OMatic/Groups.pm:209 lib/FAQ/OMatic/maintenance.pm:134
 "Go To Install/Configuration Page"
 => "Tovább a beállítások oldalra",

#: lib/FAQ/OMatic/Item.pm:83
 "New Item"
 => "Új elem",

#: lib/FAQ/OMatic/Item.pm:727
 "Parts"
 => "Elemek",

#: lib/FAQ/OMatic/Item.pm:750
 "(missing or broken file)"
 => "",

#: lib/FAQ/OMatic/Item.pm:851
 "Previous"
 => "Előző",

#: lib/FAQ/OMatic/Item.pm:869
 "Next"
 => "Következő",

#: lib/FAQ/OMatic/Item.pm:968 lib/FAQ/OMatic/Item.pm:1382
#: lib/FAQ/OMatic/Item.pm:1566
 "Moderator"
 => "Moderátor",

#: lib/FAQ/OMatic/Item.pm:970
 "(inherited from parent)"
 => "(szülő elemtől származó)",

#: lib/FAQ/OMatic/Item.pm:988
 "Category Title and Options"
 => "Kategória címe és tulajdonságai",

#: lib/FAQ/OMatic/Item.pm:989
 "Edit Category Permissions"
 => "Engedélyek beállítása (kat.)",

#: lib/FAQ/OMatic/Item.pm:990
 "Move Category"
 => "Kategória mozgatása",

#: lib/FAQ/OMatic/Item.pm:991
 "Trash Category"
 => "Kategória törlése",

#: lib/FAQ/OMatic/Item.pm:995
 "Answer Title and Options"
 => "Válasz címe és tulajdonságai",

#: lib/FAQ/OMatic/Item.pm:996
 "Edit Answer Permissions"
 => "Engedélyek beállítása (válasz)",

#: lib/FAQ/OMatic/Item.pm:997
 "Move Answer"
 => "Válasz mozgatása",

#: lib/FAQ/OMatic/Item.pm:998
 "Trash Answer"
 => "Válasz törlése",

#: lib/FAQ/OMatic/Item.pm:1004
 "%0 Title and Options"
 => "%0 címe és tulajdonságai",

#: lib/FAQ/OMatic/Item.pm:1005 lib/FAQ/OMatic/Item.pm:1006
 "Edit %0 Permissions"
 => "Engedélyek beállítása (%0)",

#: lib/FAQ/OMatic/Item.pm:1007
#, c-format
 "Move %0"
 => "%0 mozgatása",

#: lib/FAQ/OMatic/Item.pm:1008
#, c-format
 "Trash %0"
 => "%0 törlése",

#: lib/FAQ/OMatic/Item.pm:1046
 "Duplicate Answer"
 => "Válasz duplázása",

#: lib/FAQ/OMatic/Item.pm:1047
 "Duplicate Category as Answer"
 => "Kategória duplázása válaszként",

#: lib/FAQ/OMatic/Item.pm:1090
 "Convert to Answer"
 => "Válasszá alakít",

#: lib/FAQ/OMatic/Item.pm:1100
 "Convert to Category"
 => "Kategóriává alakít",

#: lib/FAQ/OMatic/Item.pm:1116 lib/FAQ/OMatic/Item.pm:1196
 "New Answer in \"%0\""
 => "Új válasz \"%0\"-ben",

#: lib/FAQ/OMatic/Item.pm:1123
 "New Subcategory of \"%0\""
 => "Új kategória \"%0\"-ben",

#: lib/FAQ/OMatic/Item.pm:1149 lib/FAQ/OMatic/Part.pm:346
 "Insert Text Here"
 => "Szöveg beszúrása ide",

#: lib/FAQ/OMatic/Item.pm:1162 lib/FAQ/OMatic/Part.pm:357
 "Insert Uploaded Text Here"
 => "Szöveg feltöltése ide",

#: lib/FAQ/OMatic/Item.pm:1212
 "Append to This Answer"
 => "Hozzáfűzés a válaszhoz",

#: lib/FAQ/OMatic/Item.pm:1330
 "This document is:"
 => "Ennek az oldalnak a címe:",

#: lib/FAQ/OMatic/Item.pm:1332
 "This document is at:"
 => "Ez a dokumentum megtalálható:",

#: lib/FAQ/OMatic/Item.pm:1376
#, c-format
 "Group %0"
 => "Csoport: %0",

#: lib/FAQ/OMatic/Item.pm:1380
 "Users giving their names"
 => "Nevüket megadó felhasználók",

#: lib/FAQ/OMatic/Item.pm:1381
 "Authenticated users"
 => "Azonosított felhasználók",

#: lib/FAQ/OMatic/Item.pm:1396
 "New Category"
 => "Új kategória",

#: lib/FAQ/OMatic/Item.pm:1398
 "New Answer"
 => "Új válasz",

#: lib/FAQ/OMatic/Item.pm:1402
 "Editing Category <b>%0</b>"
 => "A(z) <b>%0</b> kategória szerkesztése",

#: lib/FAQ/OMatic/Item.pm:1406
 "Editing Answer <b>%0</b>"
 => "A(z) <b>%0</b> válasz szerkesztése",

#: lib/FAQ/OMatic/Item.pm:1411
 "Editing %0 <b>%1</b>"
 => "Editing %0 <b>%1</b>",

#: lib/FAQ/OMatic/Item.pm:1441
 "Title:"
 => "Cím:",

#: lib/FAQ/OMatic/Item.pm:1446
 "<p>New Order for Text Parts:"
 => "<p>A szövegelemek új sorrendje:",

#: lib/FAQ/OMatic/Item.pm:1458
 "Show attributions from all parts together at bottom"
 => "Valamennyi rész tulajdonságának mutatása az oldal alján",

#: lib/FAQ/OMatic/Item.pm:1471 lib/FAQ/OMatic/Item.pm:1667
#: lib/FAQ/OMatic/Part.pm:560 lib/FAQ/OMatic/editBag.pm:122
 "Submit Changes"
 => "Változtatások mentése",

#: lib/FAQ/OMatic/Item.pm:1472 lib/FAQ/OMatic/Item.pm:1668
#: lib/FAQ/OMatic/Part.pm:561 lib/FAQ/OMatic/editBag.pm:123
 "Revert"
 => "Visszavonás",

#: lib/FAQ/OMatic/Item.pm:1492
 "Who can add a new text part to this item:"
 => "Új szövegrész hozzáadására jogosultak:",

#: lib/FAQ/OMatic/Item.pm:1494
 "Who can add a new answer or category to this category:"
 => "Kategórián belül új válasz vagy kategória hozzáadására jogosultak:",

#: lib/FAQ/OMatic/Item.pm:1496
 "Who can edit or remove existing text parts from this item:"
 => "Meglévő szövegrész eltávolítására jogosultak:",

#: lib/FAQ/OMatic/Item.pm:1498
 "Who can move answers or subcategories from this category; or turn this category into an answer or vice versa:"
 => "Válasz vagy kategória áthelyezésére, valamint kategória - válasz konvertálásra jogosultak:",

#: lib/FAQ/OMatic/Item.pm:1500
 "Who can edit the title and options of this answer or category:"
 => "A válasz vagy kategória címét és beállítását módosíthatja:",

#: lib/FAQ/OMatic/Item.pm:1502
 "Who can use untranslated HTML when editing the text of this answer or category:"
 => "HTML-formátum hozzáadására/szerkesztésére jogosult:",

#: lib/FAQ/OMatic/Item.pm:1504
 "Who can change these moderator options and permissions:"
 => "A moderátor beállításokat és a jogosultságokat módosíthatja:",

#: lib/FAQ/OMatic/Item.pm:1506
 "Who can create new bags:"
 => "Új csomag feltöltésére jogosult:",

#: lib/FAQ/OMatic/Item.pm:1508
 "Who can replace existing bags:"
 => "Meglévő csomag csréjére jogosult:",

#: lib/FAQ/OMatic/Item.pm:1510
 "Who can access the installation/configuration page (use caution!):"
 => "A telepítés/beállítások oldal elérésére jogosult (Óvatosan!):",

#: lib/FAQ/OMatic/Item.pm:1512
 "Who can use the group membership pages:"
 => "Csoporttagság oldalakat elérheti:",

#: lib/FAQ/OMatic/Item.pm:1529
 "Moderator options for category"
 => "Kaegória moderátor-beállításai",

#: lib/FAQ/OMatic/Item.pm:1533
 "Moderator options for answer"
 => "Válasz moderátor-beállításai",

#: lib/FAQ/OMatic/Item.pm:1538
 "Moderator options for"
 => "Moderátor beállítások:",

#: lib/FAQ/OMatic/Item.pm:1556
 "Name & Description"
 => "Név és leírás",

#: lib/FAQ/OMatic/Item.pm:1557
 "Setting"
 => "Beállítások",

#: lib/FAQ/OMatic/Item.pm:1558
 "Setting if Inherited"
 => "Örökölt beállítások",

#: lib/FAQ/OMatic/Item.pm:1567 lib/FAQ/OMatic/Item.pm:1604
 "(will inherit if empty)"
 => "(öröklődik, ha üres)",

#: lib/FAQ/OMatic/Item.pm:1577
 "Send mail to the moderator when someone other than the moderator edits this item:"
 => "Levélküldés a moderátornak, ha valaki más szerkeszti ezt az elemet:",

#: lib/FAQ/OMatic/Item.pm:1583 lib/FAQ/OMatic/Item.pm:1620
 "No"
 => "Nem",

#: lib/FAQ/OMatic/Item.pm:1583 lib/FAQ/OMatic/Item.pm:1620
 "Yes"
 => "Igen",

#: lib/FAQ/OMatic/Item.pm:1583 lib/FAQ/OMatic/Item.pm:1620
#: lib/FAQ/OMatic/Item.pm:1661
 "undefined"
 => "nincs meghatározva",

#: lib/FAQ/OMatic/Item.pm:1602
 "Notifier"
 => "Értesítendő",

#: lib/FAQ/OMatic/Item.pm:1603
 "Send mail to the Notifier when item is created or modified"
 => "Értesítés küldése változás vagy új elem létrehozása esetén",

#: lib/FAQ/OMatic/Item.pm:1614
 "Send mail to the Notifier when someone other than the moderator edits this item:"
 => "Levelet küld a megadott címre, ha a moderátoron kívül valaki módosítja ezt az elemet:",

#: lib/FAQ/OMatic/Item.pm:1625
 "Permissions"
 => "Engedélyek",

#: lib/FAQ/OMatic/Item.pm:1647
 "Relax: New answers and subcategories will be moderated "
 => "Relax: New answers and subcategories will be moderated ",

#: lib/FAQ/OMatic/Item.pm:1648
 "by the creator of the item, allowing that person full "
 => "by the creator of the item, allowing that person full ",

#: lib/FAQ/OMatic/Item.pm:1649
 "freedom to edit that new item."
 => "freedom to edit that new item.",

#: lib/FAQ/OMatic/Item.pm:1650
 "Don't Relax: new items will be moderated by "
 => "Don't Relax: new items will be moderated by ",

#: lib/FAQ/OMatic/Item.pm:1651
 "the moderator of this item."
 => "the moderator of this item.",

#: lib/FAQ/OMatic/Item.pm:1656 lib/FAQ/OMatic/Item.pm:1660
 "Relax"
 => "Relax",

#: lib/FAQ/OMatic/Item.pm:1656 lib/FAQ/OMatic/Item.pm:1660
 "Don't Relax"
 => "Don't Relax",

#: lib/FAQ/OMatic/Item.pm:1656
 "Inherit"
 => "Inherit",

#: lib/FAQ/OMatic/Item.pm:1690 lib/FAQ/OMatic/Item.pm:1704
 "(system default)"
 => "(alapértelmezett)",

#: lib/FAQ/OMatic/Item.pm:1696
 "defined in"
 => "defined in",

#: lib/FAQ/OMatic/Item.pm:1775
#, c-format
 "File %0 seems broken."
 => "File %0 seems broken.",

#: lib/FAQ/OMatic/Item.pm:2155
 "Category"
 => "Kategória",

#: lib/FAQ/OMatic/Item.pm:2156
 "Answer"
 => "Válasz",

#: lib/FAQ/OMatic/Item.pm:2226
 "Either someone has changed the answer or category you were editing since you received the editing form, or you submitted the same form twice."
 => "A szerkesztett válasz vagy kategória a szerkesztés kezdete óta megváltozott, vagy a változtatásokat többször küldte el.",

#: lib/FAQ/OMatic/Item.pm:2228
 "Please %0 and start again to make sure no changes are lost. Sorry for the inconvenience."
 => "Please %0 and start again to make sure no changes are lost. Sorry for the inconvenience.",

#: lib/FAQ/OMatic/Item.pm:2231
 "(Sequence number in form: %0; in item: %1)"
 => "(Sequence number in form: %0; in item: %1)",

#: lib/FAQ/OMatic/Part.pm:270
 "Edit This Text"
 => "A fenti szöveg szerkesztése",

#: lib/FAQ/OMatic/Part.pm:281
 "Duplicate This Text"
 => "A fenti szöveg megismétlése",

#: lib/FAQ/OMatic/Part.pm:292 lib/FAQ/OMatic/Part.pm:305
 "Remove This Text"
 => "A szöveg törlése",

#: lib/FAQ/OMatic/Part.pm:317
 "Replace %0 with new upload"
 => "%0 cseréje (feltöltéssel)",

#: lib/FAQ/OMatic/Part.pm:324
 "Select bag to replace with new upload"
 => "Válassza ki a cserélni kívánt csomagot",

#: lib/FAQ/OMatic/Part.pm:333
 "Upload New Bag Here"
 => "Új csomag feltöltése ide",

#: lib/FAQ/OMatic/Part.pm:498
 "Upload file:"
 => "Feltöltendő fájl:",

#: lib/FAQ/OMatic/Part.pm:503
 "Warning: file contents will <b>replace</b> previous text"
 => "Figyelem! A fájl tartalma <b>felülírja</b> a korábbi szöveget!",

#: lib/FAQ/OMatic/Part.pm:510
 "Hide Attributions"
 => "Tulajdonságok elrejtése",

#: lib/FAQ/OMatic/Part.pm:513
 "Format text as:"
 => "Szövegformázás mint:",

#: lib/FAQ/OMatic/Part.pm:523
 "Directory"
 => "Könyvtár",

#: lib/FAQ/OMatic/Part.pm:530
 "Natural text"
 => "Normál szöveg",

#: lib/FAQ/OMatic/Part.pm:534
 "Monospaced text (code, tables)"
 => "Formázott szöveg (forráskód, táblázat)",

#: lib/FAQ/OMatic/Part.pm:549
 "Untranslated HTML"
 => "Módosítás nélküli HTML",

#: lib/FAQ/OMatic/Part.pm:699 lib/FAQ/OMatic/addItem.pm:102
#: lib/FAQ/OMatic/install.pm:1177 lib/FAQ/OMatic/submitAnsToCat.pm:67
 "Answers in this category:"
 => "Válaszok ebben a kategóriában:",

#: lib/FAQ/OMatic/Slow.pm:138
#, c-format
 "This page will reload every %0 seconds,"
 => "Az oldal %0 másodpercenként újratöltődik,",

#: lib/FAQ/OMatic/Slow.pm:141
 "showing the entire process output."
 => "a folyamat teljes kimenetét mutatva.",

#: lib/FAQ/OMatic/Slow.pm:142
 "Show the tail of the process log"
 => "A folyamatnapló végének mutatása",

#: lib/FAQ/OMatic/Slow.pm:144
#, c-format
 "showing the last %0 lines of the process output."
 => "a folyamat naplójának utolsó %0 sorát mutatva.",

#: lib/FAQ/OMatic/Slow.pm:145
 "Show the entire process log"
 => "A folyamat teljes naplójának mutatása",

#: lib/FAQ/OMatic/addItem.pm:48 lib/FAQ/OMatic/delPart.pm:47
#: lib/FAQ/OMatic/editItem.pm:50 lib/FAQ/OMatic/editModOptions.pm:50
#: lib/FAQ/OMatic/faq.pm:74 lib/FAQ/OMatic/moveItem.pm:50
#: lib/FAQ/OMatic/selectBag.pm:60 lib/FAQ/OMatic/submitAnsToCat.pm:49
#: lib/FAQ/OMatic/submitCatToAns.pm:48 lib/FAQ/OMatic/submitItem.pm:48
#: lib/FAQ/OMatic/submitModOptions.pm:47 lib/FAQ/OMatic/submitPart.pm:48
 "The file (%0) doesn't exist."
 => "A fájl (%0) nem létezik.",

#: lib/FAQ/OMatic/addItem.pm:67
 "Copy of"
 => "Copy of",

#: lib/FAQ/OMatic/addItem.pm:102 lib/FAQ/OMatic/install.pm:1177
#: lib/FAQ/OMatic/submitAnsToCat.pm:67
 "Subcategories:"
 => "Alkategóriák:",

#: lib/FAQ/OMatic/appearanceForm.pm:46
 "Appearance Options"
 => "Megjelenés beállítása",

#: lib/FAQ/OMatic/appearanceForm.pm:60 lib/FAQ/OMatic/appearanceForm.pm:64
#: lib/FAQ/OMatic/appearanceForm.pm:68 lib/FAQ/OMatic/appearanceForm.pm:84
#: lib/FAQ/OMatic/appearanceForm.pm:92
 "Show"
 => "Mutatja",

#: lib/FAQ/OMatic/appearanceForm.pm:60
 "Compact"
 => "Tömören",

#: lib/FAQ/OMatic/appearanceForm.pm:60 lib/FAQ/OMatic/appearanceForm.pm:64
#: lib/FAQ/OMatic/appearanceForm.pm:68 lib/FAQ/OMatic/appearanceForm.pm:84
#: lib/FAQ/OMatic/appearanceForm.pm:92
 "Hide"
 => "Elrejti",

#: lib/FAQ/OMatic/appearanceForm.pm:62 lib/FAQ/OMatic/install.pm:803
 "expert editing commands"
 => "a haladó szerkesztési parancsokat",

#: lib/FAQ/OMatic/appearanceForm.pm:66 lib/FAQ/OMatic/install.pm:808
 "name of moderator who organizes current category"
 => "az aktuális kategória moderátorának nevét",

#: lib/FAQ/OMatic/appearanceForm.pm:70 lib/FAQ/OMatic/install.pm:813
 "last modified date"
 => "az utolsó módosítás dátumát",

#: lib/FAQ/OMatic/appearanceForm.pm:84
 "Default"
 => "Alapértelmezés",

#: lib/FAQ/OMatic/appearanceForm.pm:86 lib/FAQ/OMatic/install.pm:818
 "attributions"
 => "tulajdonságok",

#: lib/FAQ/OMatic/appearanceForm.pm:88
 "Simple"
 => "Egyszerű",

#: lib/FAQ/OMatic/appearanceForm.pm:88
 "Fancy"
 => "Fancy",

#: lib/FAQ/OMatic/appearanceForm.pm:94 lib/FAQ/OMatic/install.pm:823
 "commands for generating text output"
 => "a szöveges kimenetet készítő parancsokat",

#: lib/FAQ/OMatic/appearanceForm.pm:126
 "Accept"
 => "Beállít",

#: lib/FAQ/OMatic/authenticate.pm:55
 "Set a New Password"
 => "Új jelszó beállítása",

#: lib/FAQ/OMatic/authenticate.pm:60
 "Create a New Login"
 => "Új azonosító létrehozása",

#: lib/FAQ/OMatic/authenticate.pm:63
 "That password is invalid. If you've forgotten your old password, you can"
 => "A megadott jelszó hibás. Amennyiben elfelejtette itt megteheti:",

#: lib/FAQ/OMatic/authenticate.pm:81
#, c-format
 "New items can only be added by %0."
 => "Új eleme hozzáadására csak %0 jogosult.",

#: lib/FAQ/OMatic/authenticate.pm:83
#, c-format
 "New text parts can only be added by %0."
 => "Új szövegrész hozzáadására csak %0 jogosult.",

#: lib/FAQ/OMatic/authenticate.pm:85
#, c-format
 "Text parts can only be removed by %0."
 => "Szövegrész eltávolítására csak %0 jogosult.",

#: lib/FAQ/OMatic/authenticate.pm:89
 "This part contains raw HTML. To avoid pages with invalid HTML, the moderator has specified that only %0 can edit HTML parts. If you are %0 you may authenticate yourself with this form."
 => "Ez a rész html-kódot tartalmaz. A hibás html-kód használatának megelőzésére a terület moderátora csak %0 számára engedélyezte html-részek szerkesztését. %0-két ezen az oldalon tudja magát azonosítani.",

#: lib/FAQ/OMatic/authenticate.pm:91
#, c-format
 "Text parts can only be added by %0."
 => "Új szövegrész hozzáadására csak %0 jogosult.",

#: lib/FAQ/OMatic/authenticate.pm:93
#, c-format
 "Text parts can only be edited by %0."
 => "A szövegrészt csak %0 szerkesztheti.",

#: lib/FAQ/OMatic/authenticate.pm:96
#, c-format
 "The title and options for this item can only be edited by %0."
 => "A címet és a beállításokat csak %0 szerkesztheti.",

#: lib/FAQ/OMatic/authenticate.pm:98
#, c-format
 "The moderator options can only be edited by %0."
 => "A moderátor beállításokat csak %0 szerkesztheti.",

#: lib/FAQ/OMatic/authenticate.pm:101
 "This item can only be moved by someone who can edit both the source and destination parent items."
 => "Ezt az elemet csak olyan személy helyezheti át, aki szerkesztheti a forrás- és célkönyvtárat.",

#: lib/FAQ/OMatic/authenticate.pm:103
#, c-format
 "This item can only be moved by %0."
 => "Ezt az elemet csak %0 helyezheti át.",

#: lib/FAQ/OMatic/authenticate.pm:110
#, c-format
 "Existing bags can only be replaced by %0."
 => "Meglévő csomagot csak %0 cserélhet.",

#: lib/FAQ/OMatic/authenticate.pm:112
#, c-format
 "Bags can only be posted by %0."
 => "Csomagot csak %0 tölthet föl.",

#: lib/FAQ/OMatic/authenticate.pm:115
#, c-format
 "The FAQ-O-Matic can only be configured by %0."
 => "A beállításokat csak %0 módosíthatja.",

#: lib/FAQ/OMatic/authenticate.pm:117
 "The operation you attempted (%0) can only be done by %1."
 => "A kért műveletet (%0) csak %1 hajthatja végre.",

#: lib/FAQ/OMatic/authenticate.pm:120
 "If you have never established a password to use with FAQ-O-Matic, you can"
 => "Amennyiben még nincs azonosítója, itt létrehozhat egyet:",

#: lib/FAQ/OMatic/authenticate.pm:121
 "If you have forgotten your password, you can"
 => "Ha elfelejtette a jelszavát itt lecserélheti:",

#: lib/FAQ/OMatic/authenticate.pm:122
 "If you have already logged in earlier today, it may be that the token I use to identify you has expired. Please log in again."
 => "A bejelentkezése lejárt. Kérem, jelentkezzen be ismét.",

#: lib/FAQ/OMatic/authenticate.pm:136
 "Please offer one of the following forms of identification:"
 => "Válasszon az azonosítási lehetőségek közül:",

#: lib/FAQ/OMatic/authenticate.pm:139
 "No authentication, but my email address is:"
 => "Azonosítás nélkül; az email-címem:",

#: lib/FAQ/OMatic/authenticate.pm:140
 "Email:"
 => "Email:",

#: lib/FAQ/OMatic/authenticate.pm:147
 "Authenticated login:"
 => "Azonosított bejelentkezés:",

#: lib/FAQ/OMatic/authenticate.pm:149 lib/FAQ/OMatic/changePass.pm:71
 "Password:"
 => "Jelszó:",

#: lib/FAQ/OMatic/changePass.pm:48
 "Please enter your username, and select a password."
 => "Adja meg a felhasználói azonosítóját, és válasszon jelszót.",

#: lib/FAQ/OMatic/changePass.pm:49
 "I will send a secret number to the email address you enter to verify that it is valid."
 => "A megadott e-mail címre elküldésre kerül egy titkos kód a cím ellenőrzése végett.",

#: lib/FAQ/OMatic/changePass.pm:50
 "If you prefer not to give your email address to this web form, please contact"
 => "Amennyiben nem szeretné megadni a címét vegye fel a kapcsolatot a rendszergazdával:",

#: lib/FAQ/OMatic/changePass.pm:52
 "Please <b>do not</b> use a password you use anywhere else, as it will not be transferred or stored securely!"
 => "Figyelem! <b>Ne adjon meg</b> olyan jelszót, amit máshol is használ, mivel a továbbítása és a tárolása nem védett formában történik!",

#: lib/FAQ/OMatic/changePass.pm:73
 "Set Password"
 => "Jelszó beállítása",

#: lib/FAQ/OMatic/editBag.pm:75
 "Replace bag"
 => "Csomag cseréje",

#: lib/FAQ/OMatic/editBag.pm:81
 "Upload new bag to show in the %0 part in <b>%1</b>."
 => "Csomag feltöltése <b>%1</b> %0 részéhez.",

#: lib/FAQ/OMatic/editBag.pm:96
 "Bag name:"
 => "Csomag neve:",

#: lib/FAQ/OMatic/editBag.pm:98
 "The bag name is used as a filename, so it is restricted to only contain letters, numbers, underscores (_), hyphens (-), and periods (.). It should also carry a meaningful extension (such as .gif) so that web browsers will know what to do with the data."
 => "A csomag nevében csak betük, számok, aláhúzás (_), kötőjel valamint pont szerepelhet. Javasolt a tartalomra jellemző kiterjesztést használni (például .gif), hogy a böngésző helyesen jelenítse meg a csomagot.",

#: lib/FAQ/OMatic/editBag.pm:99
 "Hint: Leave blank and Bag Data filename will be used."
 => "Megjegyzés: Üresen hagyva a csomag neve a fájl nevével fog megegyezni.",

#: lib/FAQ/OMatic/editBag.pm:102
 "Bag data:"
 => "Csomag tartalma:",

#: lib/FAQ/OMatic/editBag.pm:106
 "Inline (Images only):"
 => "Az oldalban mutatva (csak kép):",

#: lib/FAQ/OMatic/editBag.pm:110
 "(Leave blank to keep original bag data and change only the associated information below.)"
 => "(A csomag korábbi tartalmának meghagyásához hagyja üresen. Ekkor csak a lentebb módosított adatok változnak.)",

#: lib/FAQ/OMatic/editBag.pm:114
 "If this bag is an image, fill in its dimensions."
 => "Amennyiben a csomag képfájl, adja meg a méretét.",

#: lib/FAQ/OMatic/editBag.pm:115
 "Width:"
 => "Szélesség:",

#: lib/FAQ/OMatic/editBag.pm:117
 "Height:"
 => "Magasság:",

#: lib/FAQ/OMatic/editPart.pm:147
 "Enter the answer to <b>%0</b>"
 => "Adja meg a választ a következőre: <b>%0</b>",

#: lib/FAQ/OMatic/editPart.pm:149
 "Enter a description for <b>%0</b>"
 => "Adja meg <b>%0</b> leírását",

#: lib/FAQ/OMatic/editPart.pm:151
 "Edit duplicated text for <b>%0</b>"
 => "Szöveg megismétlése a következőhöz: <b>%0</b>",

#: lib/FAQ/OMatic/editPart.pm:153
 "Enter new text for <b>%0</b>"
 => "Szöveg megadása a következőhöz: <b>%0</b>",

#: lib/FAQ/OMatic/editPart.pm:158
 "Editing the %0 text part in <b>%1</b>."
 => "A(z) <b>%1</b> %0 szövegrészének szerkesztése.",

#: lib/FAQ/OMatic/editPart.pm:172
 "If you later need to edit or delete this text, use the [Appearance] page to turn on the expert editing commands."
 => "Ha később szerkeszteni vagy törölni szeretné ezt a szöveget, használja a [Megjelenés] oldalt a szerkesztő parancsok bekapcsolásához.",

#: lib/FAQ/OMatic/install.pm:94
 "Faq-O-Matic Installer"
 => "Faq-O-Matic telepítő",

#: lib/FAQ/OMatic/install.pm:122
#, c-format
 "%0 failed: "
 => "%0 sikertelen: ",

#: lib/FAQ/OMatic/install.pm:128
 "Unknown step: \"%0\"."
 => "Ismeretlen lépés: \"%0\".",

#: lib/FAQ/OMatic/install.pm:139
 "Updating config to reflect new meta location <b>%0</b>."
 => "Beállítások frissítése a \"meta\" új helyéhez: <b>%0</b>.",

#: lib/FAQ/OMatic/install.pm:157
 "(Can't find <b>config</b> in '%0' -- assuming this is a new installation.)"
 => "(Nem találtam a %0/<b>config</b>-ot -- új telepítés feltételezve)",

#: lib/FAQ/OMatic/install.pm:181
#, c-format
 "Click here</a> to create %0."
 => "Kattintson ide</a> a %0 elkészítéséhez.",

#: lib/FAQ/OMatic/install.pm:183
 "If you want to change the CGI stub to point to another directory, edit the script and then"
 => "If you want to change the CGI stub to point to another directory, edit the script and then",

#: lib/FAQ/OMatic/install.pm:186
 "click here to use the new location"
 => "click here to use the new location",

#: lib/FAQ/OMatic/install.pm:188
 "FAQ-O-Matic stores files in two main directories.<p>The <b>meta/</b> directory path is encoded in your CGI stub (%0). It contains:"
 => "FAQ-O-Matic stores files in two main directories.<p>The <b>meta/</b> directory path is encoded in your CGI stub (%0). It contains:",

#: lib/FAQ/OMatic/install.pm:189
 "<ul><li>the <b>config</b> file that tells FAQ-O-Matic where everything else lives. That's why the CGI stub needs to know where meta/ is, so it can figure out the rest of its configuration. <li>the <b>idfile</b> file that lists user identities. Therefore, meta/ should not be accessible via the web server. <li>the <b>RCS/</b> subdirectory that tracks revisions to FAQ items. <li>various hint files that are used as FAQ-O-Matic runs. These can be regenerated automatically.</ul>"
 => "<ul><li>the <b>config</b> file that tells FAQ-O-Matic where everything else lives. That's why the CGI stub needs to know where meta/ is, so it can figure out the rest of its configuration. <li>the <b>idfile</b> file that lists user identities. Therefore, meta/ should not be accessible via the web server. <li>the <b>RCS/</b> subdirectory that tracks revisions to FAQ items. <li>various hint files that are used as FAQ-O-Matic runs. These can be regenerated automatically.</ul>",

#: lib/FAQ/OMatic/install.pm:190
 "<p>The <b>serve/</b> directory contains three subdirectories <b>item/</b>, <b>cache/</b>, and <b>bags/</b>. These directories are created and populated by the FAQ-O-Matic CGI, but should be directly accessible via the web server (without invoking the CGI)."
 => "<p>The <b>serve/</b> directory contains three subdirectories <b>item/</b>, <b>cache/</b>, and <b>bags/</b>. These directories are created and populated by the FAQ-O-Matic CGI, but should be directly accessible via the web server (without invoking the CGI).",

#: lib/FAQ/OMatic/install.pm:191
 "<ul><li>serve/item/ contains only FAQ-O-Matic formatted source files, which encode both user-entered text and the hierarchical structure of the answers and categories in the FAQ. These files are only accessed through the web server (rather than the CGI) when another FAQ-O-Matic is mirroring this one. <li>serve/cache/ contains a cache of automatically-generated HTML versions of FAQ answers and categories. When possible, the CGI directs users to the cache to reduce load on the server. (CGI hits are far more expensive than regular file loads.) <li>serve/bags/ contains image files and other ``bags of bits.'' Bit-bags can be linked to or inlined into FAQ items (in the case of images). </ul>"
 => "<ul><li>serve/item/ contains only FAQ-O-Matic formatted source files, which encode both user-entered text and the hierarchical structure of the answers and categories in the FAQ. These files are only accessed through the web server (rather than the CGI) when another FAQ-O-Matic is mirroring this one. <li>serve/cache/ contains a cache of automatically-generated HTML versions of FAQ answers and categories. When possible, the CGI directs users to the cache to reduce load on the server. (CGI hits are far more expensive than regular file loads.) <li>serve/bags/ contains image files and other ``bags of bits.'' Bit-bags can be linked to or inlined into FAQ items (in the case of images). </ul>",

#: lib/FAQ/OMatic/install.pm:203 lib/FAQ/OMatic/install.pm:218
#: lib/FAQ/OMatic/install.pm:277 lib/FAQ/OMatic/install.pm:631
 "I couldn't create <b>%0</b>: %1"
 => "Nem tudom létrehozni: %1 <b>%0</b>.",

#: lib/FAQ/OMatic/install.pm:207 lib/FAQ/OMatic/install.pm:222
#: lib/FAQ/OMatic/install.pm:634
 "Created <b>%0</b>."
 => "<b>%0</b> létrehozva.",

#: lib/FAQ/OMatic/install.pm:210 lib/FAQ/OMatic/install.pm:225
#: lib/FAQ/OMatic/install.pm:637
 "I don't have write permission to <b>%0</b>."
 => "Nincs jogom írni: <b>%0</b>.",

#: lib/FAQ/OMatic/install.pm:269
 "Created new config file."
 => "Új konfigurációs állomány létrehozva.",

#: lib/FAQ/OMatic/install.pm:283
 "The idfile exists."
 => "Az <em>idfile</em> már létezik.",

#: lib/FAQ/OMatic/install.pm:332
 "Configuration Main Menu (install module)"
 => "Beállítások főmenü (telepítési mód)",

#: lib/FAQ/OMatic/install.pm:333
 "Perform these tasks in order to prepare your FAQ-O-Matic version %0:"
 => "A FAQ-O-Matic %0 használatba vételéhez szükséges tevékenységek:",

#: lib/FAQ/OMatic/install.pm:338
 "Define configuration parameters"
 => "Rendszerparaméterek beállítása",

#: lib/FAQ/OMatic/install.pm:343 lib/FAQ/OMatic/install.pm:348
 "Set your password and turn on installer security"
 => "Állítsa be a jelszavát és kapcsolja be a telepítő védelmét",

#: lib/FAQ/OMatic/install.pm:349
#, fuzzy
 "(Need to configure \$mailCommand and \$adminAuth)"
# fuzzy # => "(Need to configure $mailCommand and $adminAuth)",
 => "",

#: lib/FAQ/OMatic/install.pm:355
 "(Installer security is on)"
 => "(Telepítő védelme: <em>aktív</em>)",

#: lib/FAQ/OMatic/install.pm:360
 "Create item, cache, and bags directories in serve dir"
 => "Az elemeket tároló könyvtárak (item, cache, bags) létrehozása",

#: lib/FAQ/OMatic/install.pm:368
 "Copy old items</a> from <tt>%0</tt> to <tt>%1</tt>."
 => "Régi elemek másolása</a>. Forrás:<tt>%0</tt>, cél: <tt>%1</tt>.",

#: lib/FAQ/OMatic/install.pm:375
 "Install any new items that come with the system"
 => "Install any new items that come with the system",

#: lib/FAQ/OMatic/install.pm:380
 "Create system default items"
 => "A rendszer alapvető elemeinek létrehozása (súgó, szemetes, stb.)",

#: lib/FAQ/OMatic/install.pm:388
 "Rebuild the cache and dependency files"
 => "A függőségek és a cache-állományok frissítése",

#: lib/FAQ/OMatic/install.pm:395
 "Install system images and icons"
 => "A rendszer képeinek és ikonjainak telepítése",

#: lib/FAQ/OMatic/install.pm:403
 "Update mirror from master now. (this can be slow!)"
 => "Tükör frissítése az eredetiből. (Ez lassú lehet!)",

#: lib/FAQ/OMatic/install.pm:409
 "Set up the maintenance cron job"
 => "A karbantartást végző cron job beállítása",

#: lib/FAQ/OMatic/install.pm:415 lib/FAQ/OMatic/install.pm:420
 "Run maintenance script manually now"
 => "Karbantartás kézi futtatása",

#: lib/FAQ/OMatic/install.pm:422
 "(Need to set up the maintenance cron job first)"
 => "(Előbb be kell állítani a karbantartást végző cron job-ot)",

#: lib/FAQ/OMatic/install.pm:430
 "Maintenance last run at:"
 => "Utolsó karbantartás időpontja:",

#: lib/FAQ/OMatic/install.pm:435
#, c-format
 "Mark the config file as upgraded to Version %0"
 => "A verziószám (%0) bejegyzése a konfigurációs állományba",

#: lib/FAQ/OMatic/install.pm:441
 "Select custom colors for your Faq-O-Matic</a> (optional)"
 => "Egyedi szinek beállítása</a> (opcionális)",

#: lib/FAQ/OMatic/install.pm:445
 "Define groups</a> (optional)"
 => "csoportok létrehozása</a> (opcionális)",

#: lib/FAQ/OMatic/install.pm:451
 "Upgrade to CGI.pm version 2.49 or newer."
 => "Frissítés a CGI.pm 2.49-es vagy frissebb verzióra.",

#: lib/FAQ/OMatic/install.pm:454
 "(optional; older versions have bugs that affect bags)"
 => "(opcionális, a korábbi verzók hibája a csomagok kezelését érinti)",

#: lib/FAQ/OMatic/install.pm:457
#, c-format
 "You are using version %0 now."
 => "A CGI.pm verziója: %0",

#: lib/FAQ/OMatic/install.pm:462
 "Bookmark this link to be able to return to this menu."
 => "Könyvjelző beállítása erre az oldalra.",

#: lib/FAQ/OMatic/install.pm:473
 "(need to turn on installer security)"
 => "(A telepítő biztonságának aktiválása szükséges)",

#: lib/FAQ/OMatic/install.pm:476
 "Other available tasks:"
 => "Egyéb tevékenységek:",

#: lib/FAQ/OMatic/install.pm:480
 "See access statistics"
 => "Statisztika megtekintése",

#: lib/FAQ/OMatic/install.pm:485
 "Examine all bags"
 => "Valamennyi csomag vizsgálata",

#: lib/FAQ/OMatic/install.pm:491
 "Check for unreferenced bags (not linked by any FAQ item)"
 => "Nem hivatkozott (nem mutat rá link sehonnan) csomagok vizsgálata.",

#: lib/FAQ/OMatic/install.pm:497
 "Empty old trash now"
 => "Kuka ürítése",

#: lib/FAQ/OMatic/install.pm:503
 "fsck (check and repair tree structure) now"
 => "A struktúra ellenőrzése és javításe (fsck)",

#: lib/FAQ/OMatic/install.pm:509
 "rebuild search database now"
 => "",

#: lib/FAQ/OMatic/install.pm:517
 "Rebuild the cache and dependency files now"
 => "A függőségek és a cache-állományok frissítése",

#: lib/FAQ/OMatic/install.pm:522
#, c-format
 "The Faq-O-Matic modules are version %0."
 => "A FAQ-O-Matic modulok verziószáma: %0.",

#: lib/FAQ/OMatic/install.pm:641
 "I wasn't able to change the permissions on <b>%0</b> to 755 (readable/searchable by all)."
 => "Nem sikerült <b>%0</b> elérhetőségét 755-re (olvasható/kereshető mindenkinek) beállítani.",

#: lib/FAQ/OMatic/install.pm:656 lib/FAQ/OMatic/install.pm:657
 "updated config file:"
 => "Beállítások frissítve:",

#: lib/FAQ/OMatic/install.pm:664
 "Redefine configuration parameters to ensure that <b>%0</b> is valid."
 => "Redefine configuration parameters to ensure that <b>%0</b> is valid.",

#: lib/FAQ/OMatic/install.pm:676
 "Jon made a mistake here; key=%0, property=%1."
 => "Jon made a mistake here; key=%0, property=%1.",

#: lib/FAQ/OMatic/install.pm:705
 "<b>Mandatory:</b> System information"
 => "<b>Kötelező:</b> Rendszerinformációk",

#: lib/FAQ/OMatic/install.pm:708
 "Identity of local FAQ-O-Matic administrator (an email address)"
 => "A FAQ-O-Matic adminisztrátor e-mail címe:",

#: lib/FAQ/OMatic/install.pm:710
 "A command FAQ-O-Matic can use to send mail. It must either be sendmail, or it must understand the -s (Subject) switch."
 => "E-mail küldésére használható parancs. A programnak ismernie kell a -s (Tárgy) kapcsolót.",

#: lib/FAQ/OMatic/install.pm:712
 "The command FAQ-O-Matic can use to install a cron job."
 => "A cron job létrehozására szolgáló parancs.",

#: lib/FAQ/OMatic/install.pm:716
 "Path to the <b>ci</b> command from the RCS package."
 => "Az RCS csomag <b>ci</b> parancsának elérési útvonala.",

#: lib/FAQ/OMatic/install.pm:719
 "Path to the <b>co</b> command from the RCS package."
 => "Az RCS csomag <b>co</b> parancsának elérési útvonala.",

#: lib/FAQ/OMatic/install.pm:722
 "<b>Mandatory:</b> Server directory configuration"
 => "<b>Kötelező:</b> Szerver-könyvtárak beállítása",

#: lib/FAQ/OMatic/install.pm:724
 "Protocol, host, and port parts of the URL to your site. This will be used to construct link URLs. Omit the trailing '/'; for example: <tt>http://www.dartmouth.edu</tt>"
 => "A FAQ-O-Matic-ban használt URL-ek protokoll, szervernév, port része. (A záró / elhagyásával, például <tt>http://www.dartmouth.edu</tt>)",

#: lib/FAQ/OMatic/install.pm:727
 "The path part of the URL used to access this CGI script, beginning with '/' and omitting any parameters after the '?'. For example: <tt>/cgi-bin/cgiwrap/jonh/faq.pl</tt>"
 => "Ennek a cgi-scriptnek az elérésére szolgáló url-ből az útvonal, /-rel kezdve, és elhagyva a paramétereket, például: <tt>/cgi-bin/cgiwrap/jonh/faq.pl</tt>",

#: lib/FAQ/OMatic/install.pm:730
 "Filesystem directory where FAQ-O-Matic will keep item files, image and other bit-bag files, and a cache of generated HTML files. This directory must be accessible directly via the http server. It might be something like /home/faqomatic/public_html/fom-serve/"
 => "Könyvtár a fájlrendszerben, ahol a FAQ-O;Matic a \"csomagokat\", képeket és a gyorsítótár állományait (előre elkészített html-fájlokat) tárolhatja. Ezt a könyvtárat a webkiszolgálónak közvetlenül el kell érnie!",

#: lib/FAQ/OMatic/install.pm:732
#, fuzzy
 "The path prefix of the URL needed to access files in <b>\$serveDir</b>. It should be relative to the root of the server (omit http://hostname:port, but include a leading '/'). It should also end with a '/'."
# fuzzy # => "Az URL-ben használandó útvonal a <b>$serveDir</b>-ben lévő állományok eléréséhez. (Elhagyva a http://gépnév:port részt, például: '/fom/').",
 => "",

#: lib/FAQ/OMatic/install.pm:735
 "<i>Optional:</i> Miscellaneous configurations"
 => "<i>Opcionális:</i> Egyéb beállítások",

#: lib/FAQ/OMatic/install.pm:740
 "Select the display language."
 => "A megjelenítés nyelve",

#: lib/FAQ/OMatic/install.pm:741
 "'en'"
 => "'hu'",

#: lib/FAQ/OMatic/install.pm:745
 "Show dates in 24-hour time or am/pm format."
 => "Az időadatok mutatása 24 órás vagy de/du formában.",

#: lib/FAQ/OMatic/install.pm:749
 "If this parameter is set, this FAQ will become a mirror of the one at the given URL. The URL should be the base name of the CGI script of the master FAQ-O-Matic."
 => "If this parameter is set, this FAQ will become a mirror of the one at the given URL. The URL should be the base name of the CGI script of the master FAQ-O-Matic.",

#: lib/FAQ/OMatic/install.pm:751
 "An HTML fragment inserted at the top of each page. You might use this to place a corporate logo."
 => "Valamennyi oldal elejére beszúrandó html-kódrészlet. (Például cégembléma megjelenítése.)",

#: lib/FAQ/OMatic/install.pm:753 lib/FAQ/OMatic/install.pm:766
 "If this field begins with <tt>file=</tt>, the text will come from the named file in the meta directory; otherwise, this field is included verbatim."
 => "Ha a mező tartalma <tt>file=</tt> -vel kezdődik, a beillesztett kódot a \"meta\" könyvtár megadott állományából veszi, egyébként a mező tartalma kerül beillesztésre.",

#: lib/FAQ/OMatic/install.pm:761
#, fuzzy
 "The <tt>width=</tt> tag in a table. If your <b>\$pageHeader</b> has <tt>align=left</tt>, you will want to make this empty."
# fuzzy # => "The <tt>width=</tt> tag in a table. If your <b>$pageHeader</b> has <tt>align=left</tt>, you will want to make this empty.",
 => "",

#: lib/FAQ/OMatic/install.pm:764
 "An HTML fragment appended to the bottom of each page. You might use this to identify the webmaster for this site."
 => "Valamennyi oldal végére beszúrandó html-kódrészlet. (Például a webmaster/adminisztrátor neve.)",

#: lib/FAQ/OMatic/install.pm:769
#, fuzzy
 "Where FAQ-O-Matic should send email when it wants to alert the administrator (usually same as \$adminAuth)"
# fuzzy # => "Where FAQ-O-Matic should send email when it wants to alert the administrator (usually same as $adminAuth)",
 => "",

#: lib/FAQ/OMatic/install.pm:771
 "If true, FAQ-O-Matic will mail the log file to the administrator whenever it is truncated."
 => "If true, FAQ-O-Matic will mail the log file to the administrator whenever it is truncated.",

#: lib/FAQ/OMatic/install.pm:774
 "User to use for RCS ci command (default is process UID)"
 => "User to use for RCS ci command (default is process UID)",

#: lib/FAQ/OMatic/install.pm:778
 "Links from cache to CGI are relative to the server root, rather than absolute URLs including hostname:"
 => "Links from cache to CGI are relative to the server root, rather than absolute URLs including hostname:",

#: lib/FAQ/OMatic/install.pm:782
 "mailto: links can be rewritten such as jonhATdartmouthDOTedu (cheesy), jonh (nameonly), or e-mail addresses suppressed entirely (hide)."
 => "A mailto: linkek megjelenési formája: jonhATdartmouthDOTedu (cheesy), jonh (nameonly), vagy az e-mail cím teljes elhagyása (hide).",

#: lib/FAQ/OMatic/install.pm:786
 "Number of seconds that authentication cookies remain valid. These cookies are stored in URLs, and so can be retrieved from a browser history file. Hence they should usually time-out fairly quickly."
 => "Number of seconds that authentication cookies remain valid. These cookies are stored in URLs, and so can be retrieved from a browser history file. Hence they should usually time-out fairly quickly.",

#: lib/FAQ/OMatic/install.pm:790
 "Number of days that trash sits in the trash category before maintenance cleans it up. '0' lets it stay forever."
 => "Napok száma ameddig a törölt elemek a \"trash\" kategóriában maradnak. Ha 0,nem kerülnek törlésre a \"trash\" kategóriából.",

#: lib/FAQ/OMatic/install.pm:793
 "<i>Optional:</i> These options set the default [Appearance] modes."
 => "<i>Optional:</i> These options set the default [Appearance] modes.",

#: lib/FAQ/OMatic/install.pm:798
 "Page rendering scheme. Do not choose 'text' as the default."
 => "Page rendering scheme. Do not choose 'text' as the default.",

#: lib/FAQ/OMatic/install.pm:826
 "<i>Optional:</i> These options fine-tune the appearance of editing features."
 => "<i>Optional:</i> These options fine-tune the appearance of editing features.",

#: lib/FAQ/OMatic/install.pm:829
 "The old [Show Edit Commands] button appears in the navigation bar."
 => "The old [Show Edit Commands] button appears in the navigation bar.",

#: lib/FAQ/OMatic/install.pm:833
 "Navigation links appear at top of page as well as at the bottom."
 => "Navigation links appear at top of page as well as at the bottom.",

#: lib/FAQ/OMatic/install.pm:837
 "Hide [Append to This Answer] and [Add New Answer in ...] buttons."
 => "Hide [Append to This Answer] and [Add New Answer in ...] buttons.",

#: lib/FAQ/OMatic/install.pm:842
 "Editing commands appear with neat-o icons rather than [In Brackets]."
 => "Editing commands appear with neat-o icons rather than [In Brackets].",

#: lib/FAQ/OMatic/install.pm:845
 "<i>Optional:</i> Other configurations that you should probably ignore if present."
 => "<i>Optional:</i> Other configurations that you should probably ignore if present.",

#: lib/FAQ/OMatic/install.pm:849
 "Draw Item titles John Nolan's way."
 => "Draw Item titles John Nolan's way.",

#: lib/FAQ/OMatic/install.pm:853
 "Hide sibling (Previous, Next) links"
 => "Hide sibling (Previous, Next) links",

#: lib/FAQ/OMatic/install.pm:857
 "Use DBM-based search databases. Faster on machines with non-broken DBM."
 => "Use DBM-based search databases. Faster on machines with non-broken DBM.",

#: lib/FAQ/OMatic/install.pm:860
 "Links from search results page point into cache (do not highlight search terms)"
 => "",

#: lib/FAQ/OMatic/install.pm:974
 "This is a command, so only letters, hyphens, and slashes are allowed."
 => "Ez egy parancs, tehát csak betük, kötőjelek, és '/' megengedett.",

#: lib/FAQ/OMatic/install.pm:1033
 "If this is your first time installing a FAQ-O-Matic, I recommend only filling in the sections marked <b>Mandatory</b>."
 => "Amennyiben először telepíti a FAQ-O-Matic rendszert, javasolt, hogy csak a <b>Kötelező</b>-nek jelölt részeket állítsa be.",

#: lib/FAQ/OMatic/install.pm:1037
 "Define"
 => "Define",

#: lib/FAQ/OMatic/install.pm:1080
 "You should <a href=\"%0\">go back</a> and fix these configurations."
 => "You should <a href=\"%0\">go back</a> and fix these configurations.",

#: lib/FAQ/OMatic/install.pm:1083
 "Rewrote configuration file."
 => "Rewrote configuration file.",

#: lib/FAQ/OMatic/install.pm:1097
 "%0 (%1) has an internal apostrophe, which will certainly make Perl choke on the config file."
 => "%0 (%1) aposztrófot tartalmaz. Ez hibát okozhat a konfigurációs állomány feldolgozásában.",

#: lib/FAQ/OMatic/install.pm:1101 lib/FAQ/OMatic/install.pm:1107
 "%0 (%1) doesn't look like a fully-qualified email address."
 => "%0 (%1) nem tűnik korrekt e-mail címnek.",

#: lib/FAQ/OMatic/install.pm:1113 lib/FAQ/OMatic/install.pm:1118
 "%0 (%1) isn't executable."
 => "%0 (%1) nem futtatható.",

#: lib/FAQ/OMatic/install.pm:1135
 "%0 has funny characters."
 => "%0 érdekes karaktereket tartalmaz.",

#: lib/FAQ/OMatic/install.pm:1170
 "To name your FAQ-O-Matic, use the [Appearance] page to show the expert editing commands, then click [Edit Category Title and Options]."
 => "To name your FAQ-O-Matic, use the [Appearance] page to show the expert editing commands, then click [Edit Category Title and Options].",

#: lib/FAQ/OMatic/install.pm:1180 lib/FAQ/OMatic/install.pm:1192
#: lib/FAQ/OMatic/install.pm:1204
 "Created category \"%0\"."
 => "Created category \"%0\".",

#: lib/FAQ/OMatic/install.pm:1182 lib/FAQ/OMatic/install.pm:1194
#: lib/FAQ/OMatic/install.pm:1206
 "<b>%0</b> already contains a file '%1'."
 => "<b>%0</b> already contains a file '%1'.",

#: lib/FAQ/OMatic/install.pm:1244
 "Copied %0 items from <tt>%1</tt> to <tt>%2</tt>."
 => "Copied %0 items from <tt>%1</tt> to <tt>%2</tt>.",

#: lib/FAQ/OMatic/install.pm:1301
 "Attempting to install cron job:"
 => "Megkísérlem beállítani a karbantartó job-ot:",

#: lib/FAQ/OMatic/install.pm:1349
 "I replaced this old crontab line, which appears to be an older one for this same FAQ:"
 => "I replaced this old crontab line, which appears to be an older one for this same FAQ:",

#: lib/FAQ/OMatic/install.pm:1358
 "I thought I installed a new cron job, but it didn't appear to take."
 => "I thought I installed a new cron job, but it didn't appear to take.",

#: lib/FAQ/OMatic/install.pm:1360
 "You better add %0 to some crontab yourself with <b><tt>crontab -e</tt></b>"
 => "You better add %0 to some crontab yourself with <b><tt>crontab -e</tt></b>",

#: lib/FAQ/OMatic/install.pm:1366
 "Cron job installed. The maintenance script should run hourly."
 => "Cron job installed. The maintenance script should run hourly.",

#: lib/FAQ/OMatic/install.pm:1422
 "Use the <u>%0</u> links to change the color of a feature."
 => "Use the <u>%0</u> links to change the color of a feature.",

#: lib/FAQ/OMatic/install.pm:1436
 "An Item Title"
 => "Az elem címe",

#: lib/FAQ/OMatic/install.pm:1444
 "A regular part is how most of your content will appear. The text colors should be most pleasantly readable on this background."
 => "A regular part is how most of your content will appear. The text colors should be most pleasantly readable on this background.",

#: lib/FAQ/OMatic/install.pm:1446 lib/FAQ/OMatic/install.pm:1458
#: lib/FAQ/OMatic/install.pm:1485
 "A new link"
 => "Új link",

#: lib/FAQ/OMatic/install.pm:1447 lib/FAQ/OMatic/install.pm:1459
#: lib/FAQ/OMatic/install.pm:1489
 "A visited link"
 => "Megtekintett link",

#: lib/FAQ/OMatic/install.pm:1449 lib/FAQ/OMatic/install.pm:1461
#: lib/FAQ/OMatic/install.pm:1494
 "A search hit"
 => "Találat (keresésnél)",

#: lib/FAQ/OMatic/install.pm:1457
 "A directory part should stand out"
 => "A directory part should stand out",

#: lib/FAQ/OMatic/install.pm:1481
 "Regular text"
 => "Normál szöveg",

#: lib/FAQ/OMatic/install.pm:1506
 "Select a color for %0:"
 => "Szín választása (%0):",

#: lib/FAQ/OMatic/install.pm:1517
 "Or enter an HTML color specification manually:"
 => "Or enter an HTML color specification manually:",

#: lib/FAQ/OMatic/install.pm:1520
 "Select"
 => "Select",

#: lib/FAQ/OMatic/install.pm:1529
 "Unrecognized config parameter"
 => "Unrecognized config parameter",

#: lib/FAQ/OMatic/install.pm:1577
#, c-format
 "Proceed to step '%0'"
 => "Proceed to step '%0'",

#: lib/FAQ/OMatic/install.pm:1708
 "You must enter the correct temporary password to install this FAQ-O-Matic. If you don't know it, remake the CGI stub to have a new one assigned."
 => "",

#: lib/FAQ/OMatic/install.pm:1711
 "Temporary password: "
 => "",

#: lib/FAQ/OMatic/moveItem.pm:114
 "Make <b>%0</b> belong to which other item?"
 => "Make <b>%0</b> belong to which other item?",

#: lib/FAQ/OMatic/moveItem.pm:118
 "No item that already has sub-items can become the parent of"
 => "No item that already has sub-items can become the parent of",

#: lib/FAQ/OMatic/moveItem.pm:120
 "No item can become the parent of"
 => "No item can become the parent of",

#: lib/FAQ/OMatic/moveItem.pm:124
 "Some destinations are not available (not clickable) because you do not have permission to edit them as currently authorized."
 => "Some destinations are not available (not clickable) because you do not have permission to edit them as currently authorized.",

#: lib/FAQ/OMatic/moveItem.pm:127
 "Click here</a> to provide better authentication."
 => "Click here</a> to provide better authentication.",

#: lib/FAQ/OMatic/moveItem.pm:133
 "Hide answers, show only categories"
 => "Válaszok elrejtése, csak kategóriák mutatása",

#: lib/FAQ/OMatic/moveItem.pm:136
 "Show both categories and answers"
 => "Kategóriák és válaszok mutatása",

#: lib/FAQ/OMatic/recent.pm:62
#, c-format
 "No items were modified in the last %0."
 => "Nincs az utóbbi %0-ban módosított elem.",

#: lib/FAQ/OMatic/recent.pm:65
 "Items modified in the last %0:"
 => "Az utóbbi %0-ben módosított elemek:",

#: lib/FAQ/OMatic/search.pm:72
 "No items matched all of these words"
 => "Nincs találat az összes szóra",

#: lib/FAQ/OMatic/search.pm:76
#, c-format
 "No items matched at least %0 of these words"
 => "Nincs találat legalább %0 szóra ezek közül",

#: lib/FAQ/OMatic/search.pm:85
 "Search results for all of these words"
 => "Keresés eredménye az összes szóra",

#: lib/FAQ/OMatic/search.pm:89
#, c-format
 "Search results for at least %0 of these words"
 => "Keresés eredménye legalább %0 szóra ezek közül",

#: lib/FAQ/OMatic/search.pm:106
 "Results may be incomplete, because the search index has not been refreshed since the most recent change to the database."
 => "Az eredmény lehet, hogy nem teljes. A keresési adatbázis nem tartalmazza a legutolsó módosítások adatait.",

#: lib/FAQ/OMatic/searchForm.pm:53
 "search for keywords"
 => "<b>Keresés kulcsszóra:</b>",

#: lib/FAQ/OMatic/searchForm.pm:58
 "Search for"
 => "Keresés:",

#: lib/FAQ/OMatic/searchForm.pm:59
 "matching"
 => "matching",

#: lib/FAQ/OMatic/searchForm.pm:61
 "all"
 => "valamennyi",

#: lib/FAQ/OMatic/searchForm.pm:62
 "any"
 => "bármely",

#: lib/FAQ/OMatic/searchForm.pm:63
 "two"
 => "két",

#: lib/FAQ/OMatic/searchForm.pm:64
 "three"
 => "három",

#: lib/FAQ/OMatic/searchForm.pm:65
 "four"
 => "négy",

#: lib/FAQ/OMatic/searchForm.pm:66
 "five"
 => "öt",

#: lib/FAQ/OMatic/searchForm.pm:68
 "words"
 => "szóra",

#: lib/FAQ/OMatic/searchForm.pm:76
 "search for recent changes"
 => "<b>A legutóbbi módosítások:</b>",

#: lib/FAQ/OMatic/searchForm.pm:82
 "Show documents"
 => "Azok a dokumentumok,",

#: lib/FAQ/OMatic/searchForm.pm:83
 "modified in the last"
 => "amelyek módosultak az utóbbi",

#: lib/FAQ/OMatic/selectBag.pm:69
 "Replace which bag?"
 => "Melyik csomagot cseréli?",

#: lib/FAQ/OMatic/stats.pm:69
 "Hits Per Day"
 => "Letöltés/nap",

#: lib/FAQ/OMatic/stats.pm:70
 "Cumulative Hits"
 => "Összes letöltés",

#: lib/FAQ/OMatic/stats.pm:74
 "New Hosts Per Day"
 => "Új kliens/nap",

#: lib/FAQ/OMatic/stats.pm:75
 "Total Hosts"
 => "Összes kliens",

#: lib/FAQ/OMatic/stats.pm:79
 "Hits Per Host"
 => "Letöltés/kliens",

#: lib/FAQ/OMatic/stats.pm:80
 "Cumulative Searches"
 => "Összes keresés",

#: lib/FAQ/OMatic/stats.pm:83
 "Submissions Per Day"
 => "Feltöltés/nap",

#: lib/FAQ/OMatic/stats.pm:84
 "Cumulative Submissions"
 => "Összes feltöltés",

#: lib/FAQ/OMatic/stats.pm:87
 "Please be patient ... the image files are generated dynamically, and can take from 20 to 50 seconds to create.\n"
 => "Kérem várjon! A grafikonok elkészítése 20-50 másodpercig is tarthat. <br>&nbsp;",

#: lib/FAQ/OMatic/stats.pm:137
 "Change View Duration"
 => "Időtartam módosítása",

#: lib/FAQ/OMatic/stats.pm:140
 "One Month"
 => "Egy hónap",

#: lib/FAQ/OMatic/stats.pm:142
 "Two Months"
 => "Két hónap",

#: lib/FAQ/OMatic/stats.pm:144
 "Three Months"
 => "Három hónap",

#: lib/FAQ/OMatic/stats.pm:146
 "History"
 => "Előzmények",

#: lib/FAQ/OMatic/submitBag.pm:74
 "Bag names may only contain letters, numbers, underscores (_), hyphens (-), and periods (.), and may not end in '.desc'. Yours was"
 => "Bag names may only contain letters, numbers, underscores (_), hyphens (-), and periods (.), and may not end in '.desc'. Yours was",

#: lib/FAQ/OMatic/submitItem.pm:61
 "Your browser or WWW cache has truncated your POST."
 => "Your browser or WWW cache has truncated your POST.",

#: lib/FAQ/OMatic/submitItem.pm:72
 "Changed the item title, was \"%0\""
 => "Changed the item title, was \"%0\"",

#: lib/FAQ/OMatic/submitItem.pm:88 lib/FAQ/OMatic/submitItem.pm:98
 "Your part order list (%0) "
 => "Your part order list (%0) ",

#: lib/FAQ/OMatic/submitItem.pm:89
 "doesn't have the same number of parts (%0) as the original item."
 => "doesn't have the same number of parts (%0) as the original item.",

#: lib/FAQ/OMatic/submitItem.pm:99
#, c-format
 "doesn't say what to do with part %0."
 => "doesn't say what to do with part %0.",

#: lib/FAQ/OMatic/submitMove.pm:51
 "The moving file (%0) is broken or missing."
 => "The moving file (%0) is broken or missing.",

#: lib/FAQ/OMatic/submitMove.pm:57
 "The newParent file (%0) is broken or missing."
 => "The newParent file (%0) is broken or missing.",

#: lib/FAQ/OMatic/submitMove.pm:66
 "The oldParent file (%0) is broken or missing."
 => "The oldParent file (%0) is broken or missing.",

#: lib/FAQ/OMatic/submitMove.pm:74
 "The new parent (%0) is the same as the old parent."
 => "The new parent (%0) is the same as the old parent.",

#: lib/FAQ/OMatic/submitMove.pm:79
 "The new parent (%0) is the same as the item you want to move."
 => "The new parent (%0) is the same as the item you want to move.",

#: lib/FAQ/OMatic/submitMove.pm:86
 "The new parent (%0) is a child of the item being moved (%1)."
 => "The new parent (%0) is a child of the item being moved (%1).",

#: lib/FAQ/OMatic/submitMove.pm:92
 "You can't move the top item."
 => "You can't move the top item.",

#: lib/FAQ/OMatic/submitMove.pm:130
#, c-format
 "moved a sub-item to %0"
 => "moved a sub-item to %0",

#: lib/FAQ/OMatic/submitMove.pm:133
#, c-format
 "moved a sub-item from %0"
 => "moved a sub-item from %0",

#: lib/FAQ/OMatic/submitPass.pm:49
 "An email address must look like 'name\@some.domain'."
 => "Az E-mail cím formátuma: 'nev@domain' legyen",

#: lib/FAQ/OMatic/submitPass.pm:51
 "If yours (%0) does and I keep rejecting it, please mail the administrator of this FAQ at %1 and tell him or her what's happening."
 => "Ha az öné (%0) ilyen, és mégis ezt a figyelmeztetést kapta, vegye fel a kapcsolatot a rendszergazdával a(z) %1 címen.",

#: lib/FAQ/OMatic/submitPass.pm:58
 "Your password may not contain spaces or carriage returns."
 => "A jelszava nem tartalmazhat szóköz, tabulátor vagy újsor karaktert.",

#: lib/FAQ/OMatic/submitPass.pm:97
 "Your Faq-O-Matic authentication secret"
 => "Az on Faq-O-Matic azonositokodja:",

#: lib/FAQ/OMatic/submitPass.pm:98
 "To validate your Faq-O-Matic password, you may either enter this secret into the Validation form:"
 => "A Faq-O-Matic jelszavanak a megerositesehez vagy az alabbi kodot kell megadni a megerosites urlapon,",

#: lib/FAQ/OMatic/submitPass.pm:99 lib/FAQ/OMatic/submitPass.pm:136
 "Secret:"
 => "Titkos kód:",

#: lib/FAQ/OMatic/submitPass.pm:100
 "Or access the following URL. Be careful when you copy and paste the URL that the line-break doesn't cut the URL short."
 => "vagy az alabbi url-t kell elerni. Az url masolasanal figyeljen arra, hogy az url-be ne keruljon sortores.",

#: lib/FAQ/OMatic/submitPass.pm:101
 "Thank you for using Faq-O-Matic."
 => "Koszonjuk, hogy hasznalja a Faq-O-Matic-ot.",

#: lib/FAQ/OMatic/submitPass.pm:102
 "(Note: if you did not sign up to use the Faq-O-Matic, someone else has attempted to log in using your name. Do not access the URL above; it will validate the password that user has supplied. Instead, send mail to %0 and I will look into the matter.)"
 => "(Megjegyzes: Amennyiben nem on hozott letre az e-mail cimevel felhasznalot a Faq-O-Matic-ban, ugy _ne_ lepjen ra a fenti url-re, mert az az on neveben bejelentkezett felhasznalo jelszavat erositene meg. Ebben az esetben forduljon az adminisztratorhoz a(z) %0 cimen.)",

#: lib/FAQ/OMatic/submitPass.pm:106
 "I couldn't mail the authentication secret to \"%0\" and I'm not sure why."
 => "I couldn't mail the authentication secret to \"%0\" and I'm not sure why.",

#: lib/FAQ/OMatic/submitPass.pm:116
 "The secret you entered is not correct."
 => "The secret you entered is not correct.",

#: lib/FAQ/OMatic/submitPass.pm:118
 "Did you copy and paste the secret or the URL completely?"
 => "Did you copy and paste the secret or the URL completely?",

#: lib/FAQ/OMatic/submitPass.pm:122
 "I sent email to you at \"%0\". It should arrive soon, containing a URL."
 => "A megadott címre (%0) egy hivatkozást tartalmazó e-mail elküldve.",

#: lib/FAQ/OMatic/submitPass.pm:126
 "Either open the URL directly, or paste the secret into the form below and click Validate."
 => "Kattintson a levélben található hivatkozásra, vagy másolja az alábbi mezőbe a levélben kapott kódot és kattintson a <em>Megerősít</em> gombra.",

#: lib/FAQ/OMatic/submitPass.pm:128
 "Thank you for taking the time to sign up."
 => "Köszönjük, hogy időt szakított a bejelentkezésre.",

#: lib/FAQ/OMatic/SearchMod.pm:293
 "zero days"
 => "napon belül",

#: lib/FAQ/OMatic/SearchMod.pm:294
 "day"
 => "nap",

#: lib/FAQ/OMatic/SearchMod.pm:295
 "two days"
 => "két napon",

#: lib/FAQ/OMatic/SearchMod.pm:296
 "week"
 => "héten",

#: lib/FAQ/OMatic/SearchMod.pm:297
 "fortnight"
 => "fortnight",

#: lib/FAQ/OMatic/SearchMod.pm:298
 "month"
 => "hónapban",

#: lib/FAQ/OMatic/SearchMod.pm:299
 "three months"
 => "negyedévben",

#: lib/FAQ/OMatic/SearchMod.pm:300
 "six months"
 => "fél évben",

#: lib/FAQ/OMatic/SearchMod.pm:301
 "year"
 => "évben",

#: lib/FAQ/OMatic/SearchMod.pm:314
 "days"
 => "napon",


);  # end of %data hash

    my $msgid;

    foreach $msgid (keys(%data))
    {
        $tx->{$msgid} = $data{$msgid};
    }
    return 1;
}
